@@ -18,7 +18,7 @@ import numpy as np
 from cr.cube.util import lazyproperty
 
 
-class _BaseCollator(object):
+class _BaseCollator:
     """Base class for all collator objects, providing shared properties.
 
     `empty_idxs` is a tuple of int element-index for each element vector with a zero
@@ -37,15 +37,6 @@ class _BaseCollator(object):
         """
         return self._dimension.element_ids
 
-    @lazyproperty
-    def _element_subvar_ids(self):
-        """something to do with being able to use str ids (aliases) for subvars.
-
-        Added by Slobodan, ask him for details. I expect the "element_ids": field in a
-        explicit-order sort transform can be a list of strs instead of a list of ints.
-        """
-        return self._dimension.element_subvar_ids
-
     @lazyproperty
     def _hidden_idxs(self):
         """frozenset of int element-idx of each vector for which to suppress display."""
@@ -115,7 +106,7 @@ class _BaseAnchoredCollator(_BaseCollator):
     def _element_order_descriptors(self):
         """tuple of (position, idx, element_id) triple for each element in dimension."""
         raise NotImplementedError(
-            "`%s` must implement `._element_order_descriptors`" % type(self).__name__
+            f"`{type(self).__name__}` must implement `._element_order_descriptors`"
         )
 
     @lazyproperty
@@ -243,22 +234,8 @@ class ExplicitOrderCollator(_BaseAnchoredCollator):
             # --- OrderedDict mapping element-id to payload-order, like {15:0, 12:1,..}.
             # --- This gives us payload-idx lookup along with duplicate and leftover
             # --- tracking.
-
-            # TODO: this has been crudely hacked to accommodate both subvar aliases or
-            # int element-ids. All that detail should be pushed down and encapsulated in
-            # some code or object that works out the type of the ids and allows this
-            # algorithm to be uniform.
             remaining_element_idxs_by_id = collections.OrderedDict(
-                (id_, (idx, subvar_id))
-                for idx, (id_, subvar_id) in enumerate(
-                    zip(self._element_ids, self._element_subvar_ids)
-                )
-            )
-            remaining_element_idxs_by_subvar_id = collections.OrderedDict(
-                (subvar_id, (idx, id_))
-                for idx, (subvar_id, id_) in enumerate(
-                    zip(self._element_subvar_ids, self._element_ids)
-                )
+                (id_, idx) for idx, id_ in enumerate(self._element_ids)
             )
 
             # --- yield (idx, id) pair for each element mentioned by id in transform,
@@ -266,27 +243,15 @@ class ExplicitOrderCollator(_BaseAnchoredCollator):
             # --- dups and leftovers.
             for element_id in self._order_spec.element_ids:
                 # --- An element-id appearing in transform but not in dimension is
-                # --- ignored. Also, an element-id that appears more than oncce in
+                # --- ignored. Also, an element-id that appears more than once in
                 # --- order-array is only used on first encounter.
-
-                # TODO: this duplication of the same logic for two cases is part of the
-                # same crude hack as above.
-
-                if element_id in remaining_element_idxs_by_subvar_id:
-                    (idx, id_) = remaining_element_idxs_by_subvar_id.pop(element_id)
-                    if id_ in remaining_element_idxs_by_id:
-                        remaining_element_idxs_by_id.pop(id_)
-                    yield idx, id_
-
                 if element_id in remaining_element_idxs_by_id:
-                    (idx, subvar_id) = remaining_element_idxs_by_id.pop(element_id)
-                    if subvar_id in remaining_element_idxs_by_subvar_id:
-                        remaining_element_idxs_by_subvar_id.pop(subvar_id)
+                    idx = remaining_element_idxs_by_id.pop(element_id)
                     yield idx, element_id
 
             # --- any remaining elements are generated in the order they originally
             # --- appeared in the cube-result.
-            for element_id, (idx, _) in remaining_element_idxs_by_id.items():
+            for element_id, idx in remaining_element_idxs_by_id.items():
                 yield idx, element_id
 
         return tuple(
@@ -389,17 +354,17 @@ class SortByValueCollator(_BaseCollator):
         These values appear in sorted order. The sequence is determined by the
         `._target_values` property defined in the subclass and the "top" and "bottom"
         anchored elements specified in the `"order": {}` dict.
+
+        If values are nan, they are placed at the end in their original payload order.
         """
         fixed_idxs = frozenset(self._top_fixed_idxs + self._bottom_fixed_idxs)
-        sorted_value_idx_pairs = sorted(
-            (
-                (value, idx)
-                for idx, value in enumerate(self._element_values)
-                if idx not in fixed_idxs
-            ),
-            reverse=self._descending,
-        )
-        return tuple(idx for _, idx in sorted_value_idx_pairs)
+        keys, nans = [], []
+        for i, val in enumerate(self._element_values):
+            if i not in fixed_idxs:
+                group = nans if self._is_nan(val) else keys
+                group.append((val, i))
+
+        return tuple(idx for _, idx in (sorted(keys, reverse=self._descending) + nans))
 
     @lazyproperty
     def _bottom_fixed_idxs(self):
@@ -431,6 +396,19 @@ class SortByValueCollator(_BaseCollator):
         """
         return self._order_spec.descending
 
+    @staticmethod
+    def _is_nan(value):
+        """True if `value` is NaN, False otherwise.
+
+        We can't use `np.isnan` directly because we want to treat any string value as
+        non-NaN (for eg sorting by label), but numpy barfs on types without NaN
+        defined.
+        """
+        try:
+            return np.isnan(value)
+        except TypeError:
+            return False
+
     def _iter_fixed_idxs(self, fixed_element_ids):
         """Generate the element-idx of each element represented by `fixed_element_ids`.
 
@@ -451,6 +429,9 @@ class SortByValueCollator(_BaseCollator):
         These values appear in sorted order. The values are determined by the
         `._subtotal_values` property defined in the subclass and the sort direction
         is derived from the `"order": {}` dict.
+
+        If subtotal values are nan, they are placed at the end in their original
+        payload order.
         """
         subtotal_values = self._subtotal_values
         n_values = len(subtotal_values)
@@ -459,7 +440,7 @@ class SortByValueCollator(_BaseCollator):
         keys, nans = [], []
         for i, val in enumerate(subtotal_values):
             neg_idx = i - n_values
-            group = nans if np.isnan(val) else keys
+            group = nans if self._is_nan(val) else keys
             group.append((val, neg_idx))
 
         return tuple(idx for _, idx in (sorted(keys, reverse=self._descending) + nans))
