@@ -5,8 +5,6 @@
 CubeSet is the main API class for manipulating Crunch.io JSON cube responses.
 """
 
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 import copy
 import json
 
@@ -20,7 +18,7 @@ from cr.cube.util import lazyproperty
 np.seterr(divide="ignore", invalid="ignore")
 
 
-class CubeSet(object):
+class CubeSet:
     """Represents a multi-cube cube-response.
 
     Also works just fine for a single cube-response passed inside a sequence, allowing
@@ -47,7 +45,7 @@ class CubeSet(object):
     @lazyproperty
     def available_measures(self):
         """frozenset of available measures of the first cube in this set."""
-        return self._cubes[0].available_measures
+        return frozenset(m for cube in self._cubes for m in cube.available_measures)
 
     @lazyproperty
     def can_show_pairwise(self):
@@ -100,7 +98,7 @@ class CubeSet(object):
     def partition_sets(self):
         """Sequence of cube-partition collections across all cubes of this cube-set.
 
-        This value might look like the following for a ca-as-0th tabbook, for example:
+        This value might look like the following for a ca-as-0th tabbook. For example::
 
             (
                 (_Strand, _Slice, _Slice),
@@ -108,7 +106,7 @@ class CubeSet(object):
                 (_Strand, _Slice, _Slice),
             )
 
-        and might often look like this for a typical slide:
+        and might often look like this for a typical slide::
 
             ((_Slice,))
 
@@ -198,7 +196,7 @@ class CubeSet(object):
         return Cube(self._cube_responses[0]).ndim == 0
 
 
-class Cube(object):
+class Cube:
     """Provides access to individual slices on a cube-result.
 
     It also provides some attributes of the overall cube-result.
@@ -225,10 +223,9 @@ class Cube(object):
         """
         try:
             dimensionality = " x ".join(dt.name for dt in self.dimension_types)
-            return "%s(name='%s', dimension_types='%s')" % (
-                type(self).__name__,
-                self.name,
-                dimensionality,
+            return (
+                f"{type(self).__name__}(name='{self.name}', "
+                f"dimension_types='{dimensionality}')"
             )
         except Exception:
             return super(Cube, self).__repr__()
@@ -572,8 +569,8 @@ class Cube(object):
             return cube_response.get("value", cube_response)
         except TypeError:
             raise TypeError(
-                "Unsupported type <%s> provided. Cube response must be JSON "
-                "(str) or dict." % type(self._cube_response_arg).__name__
+                f"Unsupported type <{type(self._cube_response_arg).__name__}> provided."
+                f" Cube response must be JSON (str) or dict."
             )
 
     @lazyproperty
@@ -649,7 +646,7 @@ class Cube(object):
 
     @lazyproperty
     def _slice_idxs(self):
-        """Iterable of contiguous int indicies for slices to be produced.
+        """Iterable of contiguous int indices for slices to be produced.
 
         This value is to help cube-section construction which does not by itself know
         how many slices are in a cube-result.
@@ -669,7 +666,7 @@ class Cube(object):
         return tuple(valid_idxs[i] for i in self._all_dimensions.dimension_order)
 
 
-class _Measures(object):
+class _Measures:
     """Provides access to measures contained in cube response."""
 
     def __init__(self, cube_dict, all_dimensions, cube_idx_arg=None):
@@ -838,7 +835,7 @@ class _Measures(object):
         return valid_counts if valid_counts.raw_cube_array is not None else None
 
 
-class _BaseMeasure(object):
+class _BaseMeasure:
     """Base class for measure objects."""
 
     def __init__(self, cube_dict, all_dimensions, cube_idx_arg=None):
@@ -857,6 +854,11 @@ class _BaseMeasure(object):
         """
         if self._flat_values is None:
             return None
+
+        # ---in case it's impossible to reshape, return None---
+        if len(self._flat_values) != np.prod(self._shape):
+            return None
+
         raw_cube_array = self._flat_values.reshape(self._shape)
         # ---must be read-only to avoid hard-to-find bugs---
         raw_cube_array.flags.writeable = False
