@@ -15,12 +15,11 @@ The three types of cube partition are the *slice*, *strand*, and *nub*, which ar
 1D, and 0D respectively.
 """
 
-from __future__ import division
-
 import math
 import numpy as np
+from tabulate import tabulate
 
-from cr.cube.enums import DIMENSION_TYPE as DT
+from cr.cube.enums import CUBE_MEASURE as CM
 from cr.cube.min_base_size_mask import MinBaseSizeMask
 from cr.cube.matrix import Assembler
 from cr.cube.measures.pairwise_significance import PairwiseSignificance
@@ -35,7 +34,7 @@ from cr.cube.util import lazyproperty
 Z_975 = 1.959964
 
 
-class CubePartition(object):
+class CubePartition:
     """A slice, a strand, or a nub drawn from a cube-response.
 
     These represent 2, 1, or 0 dimensions of a cube, respectively.
@@ -172,8 +171,8 @@ class CubePartition(object):
         # --- reject invalid types ---
         if not isinstance(value, (float, list, tuple)):
             raise TypeError(
-                "transforms.pairwise_indices.alpha, when defined, must be a list of 1 "
-                "or 2 float values between 0.0 and 1.0 exclusive. Got %r" % value
+                f"transforms.pairwise_indices.alpha, when defined, must be a list of 1 "
+                f"or 2 float values between 0.0 and 1.0 exclusive. Got {repr(value)}"
             )
 
         # --- legacy float "by-itself" case ---
@@ -181,7 +180,7 @@ class CubePartition(object):
             if not 0.0 < value < 1.0:
                 raise ValueError(
                     "alpha value, when provided, must be between 0.0 and 1.0 "
-                    "exclusive. Got %r" % value
+                    f"exclusive. Got {repr(value)}"
                 )
             return (value, None)
 
@@ -189,8 +188,8 @@ class CubePartition(object):
         for x in value[:2]:
             if not isinstance(x, float) or not 0.0 < x < 1.0:
                 raise ValueError(
-                    "transforms.pairwise_indices.alpha must be a list of 1 or 2 float "
-                    "values between 0.0 and 1.0 exclusive. Got %r" % value
+                    f"transforms.pairwise_indices.alpha must be a list of 1 or 2 float "
+                    f"values between 0.0 and 1.0 exclusive. Got {repr(value)}"
                 )
 
         if len(value) == 1:
@@ -198,6 +197,19 @@ class CubePartition(object):
 
         return tuple(sorted(value[:2]))
 
+    @lazyproperty
+    def _available_measures(self):
+        """sorted list of available CUBE_MEASURE members in the cube response."""
+        return sorted(list(self._cube.available_measures), key=lambda el: el.name)
+
+    @lazyproperty
+    def _default_contents(self):
+        """1D/2D np.float64 ndarray of counts, means or sums, if available."""
+        measure = self._available_measures[0]
+        return getattr(
+            self, {CM.COUNT: "counts", CM.MEAN: "means", CM.SUM: "sums"}[measure]
+        )
+
     @lazyproperty
     def _dimensions(self):
         """tuple of Dimension object for each dimension in cube-partition."""
@@ -248,6 +260,32 @@ class _Slice(CubePartition):
         self._population = population
         self._mask_size = mask_size
 
+    def __repr__(self):
+        """Provide text representation suitable for working at console.
+
+        Falls back to a default repr on exception, such as might occur in
+        unit tests where object need not otherwise be provided with all
+        instance variable values.
+        """
+        try:
+            dimensionality = " x ".join(dt.name for dt in self.dimension_types)
+            title = (
+                f"{type(self).__name__}(name='{self.name}', "
+                f"dimension_types='{dimensionality}')"
+            )
+            contents = [
+                [row_label] + row.tolist()
+                for row_label, row in zip(self.row_labels, self._default_contents)
+            ]
+            return (
+                f"{title}"
+                f"\nShowing: {self._available_measures[0].name}"
+                f"\n{tabulate(contents, [''] + self.column_labels.tolist())}"
+                f"\nAvailable measures: {str(self._available_measures)}"
+            )
+        except Exception:
+            return super(_Slice, self).__repr__()  # noqa
+
     # ---interface ---------------------------------------------------
 
     @lazyproperty
@@ -314,7 +352,7 @@ class _Slice(CubePartition):
 
         `std_deviation = sqrt(variance)`
         """
-        return np.sqrt(self._column_variances)
+        return np.sqrt(self._assembler.column_proportion_variances)
 
     @lazyproperty
     def column_std_err(self):
@@ -322,11 +360,11 @@ class _Slice(CubePartition):
 
         `std_error = sqrt(variance/N)`
         """
-        return np.sqrt(self._column_variances / self.columns_margin)
+        return self._assembler.column_std_err
 
     @lazyproperty
     def column_unweighted_bases(self):
-        """2D np.float64 ndarray of unweighted column-proportion denominator per cell."""
+        """2D np.float64 ndarray of unweighted col-proportion denominator per cell."""
         return self._assembler.column_unweighted_bases
 
     @lazyproperty
@@ -414,11 +452,11 @@ class _Slice(CubePartition):
         if not self._rows_have_numeric_value:
             return None
 
-        rows_margin = self.rows_margin
-        # TODO: This is a hack for X_MR slices, where rows-margin is 2D. Figure out a
-        # better way to do this, perhaps using ranges.
-        if rows_margin.ndim > 1:
-            rows_margin = rows_margin[:, 0]
+        # TODO: This is a hack for X_Array slices, where rows-margin is undefined.
+        # I think this probably shouldn't be defined across arrays, but to minimize
+        # test damage, we use the first column of the weighted bases, which is
+        # equal to the rows_margin for CAT_X_CAT and always exists for others.
+        rows_margin = self.row_weighted_bases[:, 0]
 
         scale_total = np.nansum(self._rows_dimension_numeric_values * rows_margin)
         not_a_nan_mask = ~np.isnan(self._rows_dimension_numeric_values)
@@ -475,13 +513,10 @@ class _Slice(CubePartition):
         underlying scale values are based on the numeric values of the opposing
         *rows-dimension* elements.
 
-        This value is `None` if no row element has been assigned a numeric value.
+        This value is `None` if no row element has a numeric value assigned or if
+        the columns-weighted-base is `None` (eg an array variable in the row dim).
         """
-        return (
-            self.columns_scale_mean_stddev / np.sqrt(self.columns_margin)
-            if self._rows_have_numeric_value
-            else None
-        )
+        return self._assembler.columns_scale_mean_stderr
 
     @lazyproperty
     def columns_scale_median(self):
@@ -514,11 +549,11 @@ class _Slice(CubePartition):
         if not self._rows_have_numeric_value:
             return None
 
-        rows_margin = self.rows_margin
-
-        # --- hack to accommodate 2D rows-margin of an X_MR slice ---
-        if len(rows_margin.shape) > 1:
-            rows_margin = rows_margin[:, 0]
+        # TODO: This is a hack for X_Array slices, where rows-margin is undefined.
+        # I think this probably shouldn't be defined across arrays, but to minimize
+        # test damage, we use the first column of the weighted bases, which is
+        # equal to the rows_margin for CAT_X_CAT and always exists for others.
+        rows_margin = self.row_weighted_bases[:, 0]
 
         not_a_nan_mask = ~np.isnan(self._rows_dimension_numeric_values)
         numeric_values = self._rows_dimension_numeric_values[not_a_nan_mask]
@@ -553,6 +588,16 @@ class _Slice(CubePartition):
         """tuple of int index of each subtotal row in slice."""
         return self._assembler.inserted_row_idxs
 
+    @lazyproperty
+    def derived_column_idxs(self):
+        """tuple of int index of each derived column-element in slice."""
+        return self._assembler.derived_column_idxs
+
+    @lazyproperty
+    def derived_row_idxs(self):
+        """tuple of int index of each derived row-element in slice."""
+        return self._assembler.derived_row_idxs
+
     @lazyproperty
     def is_empty(self):
         return any(s == 0 for s in self.shape)
@@ -601,18 +646,7 @@ class _Slice(CubePartition):
         column in the same row with a confidence interval meeting the threshold defined
         for this analysis.
         """
-        # If overlaps are defined, calculate significance based on them
-        if (
-            self.dimension_types[-1] == DT.MR
-            and self._cube.overlaps is not None
-            and self._cube.valid_overlaps is not None
-        ):
-            return self._assembler.pairwise_indices(self._alpha, self._only_larger)
-
-        # If overlaps are not defined, default to the legacy way of calculating sig
-        return PairwiseSignificance.pairwise_indices(
-            self, self._alpha, self._only_larger
-        )
+        return self._assembler.pairwise_indices(self._alpha, self._only_larger)
 
     @lazyproperty
     def pairwise_indices_alt(self):
@@ -624,18 +658,7 @@ class _Slice(CubePartition):
         if self._alpha_alt is None:
             return None
 
-        # If overlaps are defined, calculate significance based on them
-        if (
-            self.dimension_types[-1] == DT.MR
-            and self._cube.overlaps is not None
-            and self._cube.valid_overlaps is not None
-        ):
-            return self._assembler.pairwise_indices(self._alpha_alt, self._only_larger)
-
-        # If no overlaps are defined, default to legacy way of calculating pw indices
-        return PairwiseSignificance.pairwise_indices(
-            self, self._alpha_alt, self._only_larger
-        )
+        return self._assembler.pairwise_indices(self._alpha_alt, self._only_larger)
 
     @lazyproperty
     def pairwise_means_indices(self):
@@ -682,48 +705,12 @@ class _Slice(CubePartition):
             )
 
     def pairwise_significance_p_vals(self, column_idx):
-        """2D ndarray of pairwise-significance p-vals matrices for column idx.
-
-        For cubes where the last dimension is categorical, column idxs represent
-        specific categories.
-
-        For cubes where the last dimension is a multiple response, each subvariable
-        pairwise significance matrix is a 2D ndarray of the p-vals for the selected
-        subvariable index (the selected column).
-        """
-
-        # If overlaps are defined, calculate significance based on them
-        if (
-            self.dimension_types[-1] == DT.MR
-            and self._cube.overlaps is not None
-            and self._cube.valid_overlaps is not None
-        ):
-            return self._assembler.pairwise_significance_p_vals(column_idx)
-
-        # If overlaps are not defined, default to the old-way of calculation
-        return PairwiseSignificance(self).values[column_idx].p_vals
+        """2D ndarray of pairwise-significance p-vals matrices for column idx."""
+        return self._assembler.pairwise_significance_p_vals(column_idx)
 
     def pairwise_significance_t_stats(self, column_idx):
-        """return 2D ndarray of pairwise-significance t-stats matrices for subvariable.
-
-        For cubes where the last dimension is categorical, column idxs represent
-        specific categories.
-
-        For cubes where the last dimension is a multiple response, each subvariable
-        pairwise significance matrix is a 2D ndarray of the t-stats for the selected
-        subvariable index (the selected column).
-        """
-
-        # If overlaps are defined, calculate significance based on them
-        if (
-            self.dimension_types[-1] == DT.MR
-            and self._cube.overlaps is not None
-            and self._cube.valid_overlaps is not None
-        ):
-            return self._assembler.pairwise_significance_t_stats(column_idx)
-
-        # If overlaps are not defined, default to the old-way of calculation
-        return PairwiseSignificance(self).values[column_idx].t_stats
+        """return 2D ndarray of pairwise-significance t-stats for selected column."""
+        return self._assembler.pairwise_significance_t_stats(column_idx)
 
     def pairwise_significance_means_p_vals(self, column_idx):
         """Optional 2D ndarray of means significance p-vals matrices for column idx."""
@@ -765,23 +752,20 @@ class _Slice(CubePartition):
         """2D np.float64 ndarray of population counts per cell.
 
         The (estimated) population count is computed based on the `population` value
-        provided when the Slice is created. It is also adjusted to account for any
-        filters that were applied as part of the query.
+        provided when the Slice is created (`._population`). It is also adjusted to
+        account for any filters that were applied as part of the query
+        (`._cube.population_fraction`).
 
-        If any of the dimensions (rows or columns) is a categorical date, the
-        appropriate percentages are used, to calculate the population counts, so as to
-        be the total amount among categorical dates.
+        `._population` and `_cube.population_fraction` are both scalars and so do not
+        affect sort order.
 
-        Otherwise, table percents are used to calculate population counts.
+        The proportion used depends on the dimension types, so get from assembler.
         """
-        proportions = (
-            self.row_proportions
-            if self.rows_dimension_type in (DT.CAT_DATE, DT.CA_SUBVAR)
-            else self.column_proportions
-            if self.columns_dimension_type in (DT.CAT_DATE, DT.CA_SUBVAR)
-            else self.table_proportions
+        return (
+            self._assembler.population_proportions
+            * self._population
+            * self._cube.population_fraction
         )
-        return proportions * self._population * self._cube.population_fraction
 
     @lazyproperty
     def population_counts_moe(self):
@@ -799,13 +783,7 @@ class _Slice(CubePartition):
         applied in these specific cases (like the `row_std_err` or `column_std_err`).
         If categorical dates are not involved, the standard `table_std_err` is used.
         """
-        std_err = (
-            self.row_std_err
-            if self.rows_dimension_type == DT.CAT_DATE
-            else self.column_std_err
-            if self.columns_dimension_type == DT.CAT_DATE
-            else self.table_std_err
-        )
+        std_err = self._assembler.population_std_err
         total_filtered_population = self._population * self._cube.population_fraction
         return Z_975 * total_filtered_population * std_err
 
@@ -880,17 +858,12 @@ class _Slice(CubePartition):
     @lazyproperty
     def row_std_dev(self):
         """2D np.float64 ndarray of standard deviation for row percentages."""
-        return np.sqrt(self._row_variance)
+        return np.sqrt(self._assembler.row_proportion_variances)
 
     @lazyproperty
     def row_std_err(self):
         """2D np.float64 ndarray of standard errors for row percentages."""
-        rows_margin = (
-            self.rows_margin  # --- no need to cast (MR dim involved)
-            if len(self.rows_margin.shape) > 1
-            else self.rows_margin[:, np.newaxis]  # --- cast to actual vector column
-        )
-        return np.sqrt(self._row_variance / rows_margin)
+        return self._assembler.row_std_err
 
     @lazyproperty
     def row_unweighted_bases(self):
@@ -1000,11 +973,11 @@ class _Slice(CubePartition):
         if not self._columns_have_numeric_value:
             return None
 
-        columns_margin = self.columns_margin
-        # TODO: This is a hack for MR_X slices, where columns-margin is 2D. Figure out
-        # a better way to do this, perhaps using ranges.
-        if len(columns_margin.shape) > 1:
-            columns_margin = columns_margin[0]
+        # TODO: This is a hack for X_Array slices, where columns-margin is undefined.
+        # I think this measure probably also shouldn't be defined across arrays, but to
+        # minimize test damage, we use the first row of the row weighted bases, which is
+        # equal to the columnss_margin for CAT_X_CAT and always exists for others.
+        columns_margin = self.column_weighted_bases[0, :]
 
         scale_total = np.nansum(self._columns_dimension_numeric_values * columns_margin)
         not_a_nan_mask = ~np.isnan(self._columns_dimension_numeric_values)
@@ -1031,13 +1004,10 @@ class _Slice(CubePartition):
         the underlying scale values are based on the numeric values of the opposing
         *columns-dimension* elements.
 
-        This value is `None` if no column element has an assigned numeric value.
+        This value is `None` if no column element has a numeric value assigned or if
+        the rows-weighted-base is `None` (eg an array variable in the column dim).
         """
-        return (
-            self.rows_scale_mean_stddev / np.sqrt(self.rows_margin)
-            if self._columns_have_numeric_value
-            else None
-        )
+        return self._assembler.rows_scale_mean_stderr
 
     @lazyproperty
     def rows_scale_median(self):
@@ -1070,11 +1040,11 @@ class _Slice(CubePartition):
         if not self._columns_have_numeric_value:
             return None
 
-        columns_margin = self.columns_margin
-
-        # --- hack to accommodate the 2D columns-margin of an MR_X slice ---
-        if len(columns_margin.shape) > 1:
-            columns_margin = columns_margin[0]
+        # TODO: This is a hack for X_Array slices, where columns-margin is undefined.
+        # I think this measure probably also shouldn't be defined across arrays, but to
+        # minimize test damage, we use the first row of the row weighted bases, which is
+        # equal to the columnss_margin for CAT_X_CAT and always exists for others.
+        columns_margin = self.column_weighted_bases[0, :]
 
         not_a_nan_index = ~np.isnan(self._columns_dimension_numeric_values)
         numeric_values = self._columns_dimension_numeric_values[not_a_nan_index]
@@ -1139,23 +1109,6 @@ class _Slice(CubePartition):
         """
         return self._assembler.table_base
 
-    @lazyproperty
-    def table_base_unpruned(self):
-        """np.float64 scalar or a 1D or 2D ndarray of np.float64 representing table base.
-
-        This value includes hidden vectors, those with either a hide transform on
-        their element or that have been pruned (because their base (N) is zero). This
-        does not affect a scalar value but when the return value is an ndarray, the
-        shape may be different than the array returned by `.table_base`.
-
-        A multiple-response (MR) dimension produces an array of table-base values
-        because each element (subvariable) of the dimension represents a logically
-        distinct question which may not have been asked of all respondents. When both
-        dimensions are MR, the return value is a 2D ndarray. A CAT_X_CAT slice produces
-        a scalar value for this property.
-        """
-        return self._assembler.table_base_unpruned
-
     @lazyproperty
     def table_margin(self):
         """Scalar or 1D/2D np.float64 ndarray of weighted-N table.
@@ -1168,24 +1121,6 @@ class _Slice(CubePartition):
         """
         return self._assembler.table_margin
 
-    @lazyproperty
-    def table_margin_unpruned(self):
-        """np.float64 scalar or a 1D or 2D ndarray of np.float64 table margin.
-
-        This value includes hidden vectors, those with either a hide transform on
-        their element or that have been pruned (because their base (N) is zero). Also,
-        it does not include inserted subtotals. This
-        does not affect a scalar value but when the return value is an ndarray, the
-        shape may be different than the array returned by `.table_margin`.
-
-        A matrix with a multiple-response (MR) dimension produces an array of
-        table-margin values because each element (subvariable) of the dimension
-        represents a logically distinct question which may not have been asked of all
-        respondents. When both dimensions are MR, the return value is a 2D ndarray.
-        A CAT_X_CAT matrix produces a scalar value for this property.
-        """
-        return self._assembler.table_margin_unpruned
-
     @lazyproperty
     def table_name(self):
         """Provides differentiated name for each stacked table of a 3D cube."""
@@ -1194,7 +1129,7 @@ class _Slice(CubePartition):
 
         title = self._cube.name
         table_name = self._cube.dimensions[0].valid_elements[self._slice_idx].label
-        return "%s: %s" % (title, table_name)
+        return f"{title}: {table_name}"
 
     @lazyproperty
     def table_percentages(self):
@@ -1203,16 +1138,7 @@ class _Slice(CubePartition):
     @lazyproperty
     def table_proportions(self):
         """2D ndarray of np.float64 fraction of table count each cell contributes."""
-        table_margin = self.table_margin
-        rows_dimension_type = self._rows_dimension.dimension_type
-
-        # --- table-margin can be scalar, 2D, or two cases of 1D. A scalar, 2D, and one
-        # --- of the 1D table-margins broadcast fine, but the MR-X-CAT case needs
-        # --- transposition to get the broadcasting right.
-        with np.errstate(divide="ignore", invalid="ignore"):
-            if rows_dimension_type == DT.MR_SUBVAR and table_margin.ndim == 1:
-                return (self.counts.T / table_margin).T
-            return self.counts / table_margin
+        return self._assembler.table_proportions
 
     @lazyproperty
     def table_proportions_moe(self):
@@ -1228,7 +1154,7 @@ class _Slice(CubePartition):
     @lazyproperty
     def table_std_dev(self):
         """2D np.float64 ndarray of std-dev of table-percent for each table cell."""
-        return np.sqrt(self._table_proportion_variance)
+        return np.sqrt(self._assembler.table_proportion_variances)
 
     @lazyproperty
     def table_std_err(self):
@@ -1236,7 +1162,7 @@ class _Slice(CubePartition):
 
         A cell value can be np.nan under certain conditions.
         """
-        return self._assembler.table_stderrs
+        return self._assembler.table_std_err
 
     @lazyproperty
     def table_unweighted_bases(self):
@@ -1264,6 +1190,28 @@ class _Slice(CubePartition):
                 "measure"
             )
 
+    @lazyproperty
+    def table_base_range(self):
+        """[min, max] np.float64 ndarray range of the table_base (table-unweighted-base)
+
+        A CAT_X_CAT has a scalar for all table-unweighted-bases, but arrays have more than
+        one table-weighted-base. This collapses all the values them to the range, and
+        it is "unpruned", meaning that it is calculated before any hiding or removing
+        of empty rows/columns.
+        """
+        return self._assembler.table_base_range
+
+    @lazyproperty
+    def table_margin_range(self):
+        """[min, max] np.float64 ndarray range of the table_margin (table-weighted-base)
+
+        A CAT_X_CAT has a scalar for all table-weighted-bases, but arrays have more than
+        one table-weighted-base. This collapses all of the values to a range, and
+        it is "unpruned", meaning that it is calculated before any hiding or removing
+        of empty rows/columns.
+        """
+        return self._assembler.table_margin_range
+
     @lazyproperty
     def unweighted_counts(self):
         """2D np.float64 ndarray of unweighted count for each slice matrix cell."""
@@ -1290,12 +1238,6 @@ class _Slice(CubePartition):
         """
         return Assembler(self._cube, self._dimensions, self._slice_idx)
 
-    @lazyproperty
-    def _column_variances(self):
-        """Variance for column percentages."""
-        p = self.column_proportions
-        return p * (1 - p)
-
     @lazyproperty
     def _columns_dimension(self):
         return self._dimensions[1]
@@ -1347,12 +1289,6 @@ class _Slice(CubePartition):
             )
         )
 
-    @lazyproperty
-    def _row_variance(self):
-        """2D np.float64 ndarray of row-percentage variance for each cell."""
-        p = self.row_proportions
-        return p * (1 - p)
-
     @lazyproperty
     def _rows_dimension(self):
         return self._dimensions[0]
@@ -1371,12 +1307,6 @@ class _Slice(CubePartition):
         """True when one or more row elements have an assigned numeric-value."""
         return not np.all(np.isnan(self._rows_dimension_numeric_values))
 
-    @lazyproperty
-    def _table_proportion_variance(self):
-        """2D ndarray of np.float64 table-proportion variance for each matrix cell."""
-        p = self.table_proportions
-        return p * (1 - p)
-
     @lazyproperty
     def _transform_dicts(self):
         """Pair of dict (rows_dimension_transforms, columns_dimension_transforms).
@@ -1406,6 +1336,31 @@ class _Strand(CubePartition):
         self._slice_idx = slice_idx
         self._mask_size = mask_size
 
+    def __repr__(self):
+        """Provide text representation suitable for working at console.
+
+        Falls back to a default repr on exception, such as might occur in
+        unit tests where object need not otherwise be provided with all
+        instance variable values.
+        """
+        try:
+            title = (
+                f"{type(self).__name__}(name='{self.name}', "
+                f"dimension_type='{self.dimension_types[0].name}')"
+            )
+            contents = [
+                [row_label, row]
+                for row_label, row in zip(self.row_labels, self._default_contents)
+            ]
+            return (
+                f"{title}"
+                f"\nShowing: {self._available_measures[0].name}"
+                f"\n{tabulate(contents, ['', self.name])}"
+                f"\nAvailable measures: {str(self._available_measures)}"
+            )
+        except Exception:
+            return super(_Strand, self).__repr__()  # noqa
+
     @lazyproperty
     def counts(self):
         """1D np.float64 ndarray of (weighted) count for each row of strand.
@@ -1414,6 +1369,11 @@ class _Strand(CubePartition):
         """
         return self._assembler.weighted_counts
 
+    @lazyproperty
+    def derived_row_idxs(self):
+        """tuple of int index of each derived row-element in this strand."""
+        return self._assembler.derived_row_idxs
+
     @lazyproperty
     def inserted_row_idxs(self):
         """tuple of int index of each inserted row in this strand.
@@ -1470,16 +1430,10 @@ class _Strand(CubePartition):
         provided when the Strand is created. It is also adjusted to account for any
         filters that were applied as part of the query.
         """
-        # ---If the only dimension is a categorical date, we don't need to break up
-        # ---the population counts between its elements - it's constant throughout time
-        if self.rows_dimension_type == DT.CAT_DATE:
-            return np.full(
-                self.table_proportions.shape,
-                self._population * self._cube.population_fraction,
-            )
-
         return (
-            self.table_proportions * self._population * self._cube.population_fraction
+            self._assembler.population_proportions
+            * self._population
+            * self._cube.population_fraction
         )
 
     @lazyproperty
@@ -1493,7 +1447,11 @@ class _Strand(CubePartition):
         table margin is 0.
         """
         total_filtered_population = self._population * self._cube.population_fraction
-        return Z_975 * total_filtered_population * self.table_proportion_stderrs
+        return (
+            Z_975
+            * total_filtered_population
+            * self._assembler.population_proportion_stderrs
+        )
 
     @lazyproperty
     def row_count(self):
@@ -1673,7 +1631,7 @@ class _Strand(CubePartition):
         """Only for CA-as-0th case, provides differentiated names for stacked tables."""
         title = self._cube.name
         table_name = self._cube.dimensions[0].valid_elements[self._slice_idx].label
-        return "%s: %s" % (title, table_name)
+        return f"{title}: {table_name}"
 
     @lazyproperty
     def table_percentages(self):
@@ -1782,20 +1740,24 @@ class _Nub(CubePartition):
 
     @lazyproperty
     def is_empty(self):
+        """True if the partition has no counts, False otherwise"""
         if self.unweighted_count <= 0:
             return True
         return math.isnan(self.unweighted_count)
 
     @lazyproperty
     def means(self):
+        """Float scalar representing the mean."""
         return self._scalar.means
 
     @lazyproperty
     def table_base(self):
+        """Int scalar of the unweighted N of the table."""
         return self._scalar.table_base
 
     @lazyproperty
     def unweighted_count(self):
+        """Integer scalar of total unweighted count of the table"""
         return self._cube.unweighted_counts
 
     # ---implementation (helpers)-------------------------------------
