@@ -7,17 +7,17 @@ import enum
 from cr.cube.util import lazyproperty
 
 
-class _DimensionType(object):
+class _DimensionType:
     """Member of the DIMENSION_TYPE enumeration."""
 
     def __init__(self, name):
         self._name = name
 
     def __repr__(self):
-        return "<DIMENSION_TYPE.%s>" % self._name
+        return f"<DIMENSION_TYPE.{self._name}>"
 
     def __str__(self):
-        return "DIMENSION_TYPE.%s" % self._name
+        return f"DIMENSION_TYPE.{self._name}"
 
     @lazyproperty
     def name(self):
@@ -25,7 +25,7 @@ class _DimensionType(object):
         return self._name
 
 
-class DIMENSION_TYPE(object):
+class DIMENSION_TYPE:
     """Enumerated values representing the various types of dimension."""
 
     # ---member definitions---
@@ -63,18 +63,27 @@ class COLLATION_METHOD(enum.Enum):
     """Enumerated values representing the methods of sorting dimension elements."""
 
     EXPLICIT_ORDER = "explicit"
+    LABEL = "label"
     MARGINAL = "marginal"
     OPPOSING_ELEMENT = "opposing_element"
     OPPOSING_INSERTION = "opposing_insertion"
     PAYLOAD_ORDER = "payload_order"
     UNIVARIATE_MEASURE = "univariate_measure"
 
+    @classmethod
+    def has_value(cls, value):
+        return value in cls._value2member_map_
+
 
 class MARGINAL(enum.Enum):
     """Enumerated values representing the (second-order) marginals."""
 
+    BASE = "unweighted_base"
+    MARGIN = "weighted_base"
+    MARGIN_PROPORTION = "table_proportion"
     SCALE_MEAN = "scale_mean"
     SCALE_MEAN_STDDEV = "scale_mean_stddev"
+    SCALE_MEAN_STDERR = "scale_mean_stderr"
     SCALE_MEDIAN = "scale_median"
 
 
@@ -93,20 +102,34 @@ class MEASURE(enum.Enum):
     COLUMN_BASE_WEIGHTED = "col_base_weighted"
     COLUMN_INDEX = "col_index"
     COLUMN_PERCENT = "col_percent"
+    COLUMN_PERCENT_MOE = "col_percent_moe"
     COLUMN_SHARE_SUM = "col_share_sum"
+    COLUMN_STDDEV = "col_std_dev"
+    COLUMN_STDERR = "col_std_err"
     MEAN = "mean"
     POPULATION = "population"
+    POPULATION_MOE = "population_moe"
+    PVALUES = "p_value"
     ROW_BASE_UNWEIGHTED = "row_base_unweighted"
     ROW_BASE_WEIGHTED = "row_base_weighted"
     ROW_PERCENT = "row_percent"
+    ROW_PERCENT_MOE = "row_percent_moe"
     ROW_SHARE_SUM = "row_share_sum"
+    ROW_STDDEV = "row_std_dev"
+    ROW_STDERR = "row_std_err"
+    STDDEV = "stddev"
     SUM = "sum"
     TABLE_BASE_UNWEIGHTED = "table_base_unweighted"
     TABLE_BASE_WEIGHTED = "table_base_weighted"
-    TABLE_STDERR = "table_stderr"
+    TABLE_PERCENT = "table_percent"
+    TABLE_PERCENT_MOE = "table_percent_moe"
+    TABLE_STDDEV = "table_std_dev"
+    TABLE_STDERR = "table_std_err"
     TOTAL_SHARE_SUM = "total_share_sum"
     UNWEIGHTED_COUNT = "count_unweighted"
+    UNWEIGHTED_VALID_COUNT = "unweighted_valid_count"
     WEIGHTED_COUNT = "count_weighted"
+    WEIGHTED_VALID_COUNT = "weighted_valid_count"
     Z_SCORE = "z_score"
 
 
