@@ -8,8 +8,6 @@ rows according to the dimension *order* transforms, and to hide rows that are ei
 hidden by the user or "pruned" because they contain no observations.
 """
 
-from __future__ import division
-
 import numpy as np
 
 from cr.cube.collator import (
@@ -22,7 +20,7 @@ from cr.cube.stripe.measure import StripeMeasures
 from cr.cube.util import lazyproperty
 
 
-class StripeAssembler(object):
+class StripeAssembler:
     """Provides measures, marginals, and totals for a (1D) strand cube-slice.
 
     An assembled stripe measure is a 1D ndarray reflecting all ordering, insertion, and
@@ -42,6 +40,29 @@ class StripeAssembler(object):
         self._ca_as_0th = ca_as_0th
         self._slice_idx = slice_idx
 
+    @lazyproperty
+    def derived_row_idxs(self):
+        """tuple of int index of each derived row-element in this stripe.
+
+        An element is derived if it's a subvariable of a multiple response dimension,
+        which has been produced by the zz9, and inserted into the response data.
+
+        All other elements, including regular MR and CA subvariables, as well as
+        categories of CAT dimensions, are not derived. Subtotals are also not derived
+        in this sense, because they're not even part of the data (elements).
+        """
+        return tuple(
+            element_idx
+            for element_idx, derived in enumerate(
+                np.array(
+                    [e.derived for e in self._rows_dimension.valid_elements]
+                    # ---Subtotals are not data elements, and hence not derived
+                    + [False for _ in self._rows_dimension.subtotals]
+                )[self._row_order]
+            )
+            if derived
+        )
+
     @lazyproperty
     def inserted_row_idxs(self):
         """tuple of int index of each inserted row in this stripe.
@@ -59,6 +80,28 @@ class StripeAssembler(object):
         """
         return self._assemble_vector(self._measures.means.blocks)
 
+    @lazyproperty
+    def population_proportions(self):
+        """1D np.float64 population-proportion for each row
+
+        Generally equal to the table_proprotions, but because we don't divide the
+        population when the row is a CAT_DATE, can also be all 1s. Used to calculate
+        the population_counts.
+        """
+        return self._assemble_vector(self._measures.population_proportions.blocks)
+
+    @lazyproperty
+    def population_proportion_stderrs(self):
+        """1D np.float64 population-proportion-standard-error for each row
+
+        Generally equal to the table_proprotion_standard_error, but because we don't
+        divide the population when the row is a CAT_DATE, can also be all 0s. Used to
+        calculate the population_counts_moe.
+        """
+        return self._assemble_vector(
+            self._measures.population_proportion_stderrs.blocks
+        )
+
     @lazyproperty
     def row_count(self):
         """int count of rows in this stripe.
@@ -76,8 +119,7 @@ class StripeAssembler(object):
         row.
         """
         return np.array(
-            [e.label for e in self._rows_dimension.valid_elements]
-            + [s.label for s in self._rows_dimension.subtotals]
+            self._rows_dimension.element_labels + self._rows_dimension.subtotal_labels
         )[self._row_order]
 
     @lazyproperty
@@ -251,7 +293,7 @@ class StripeAssembler(object):
 # === ORDER HELPERS ===
 
 
-class _BaseOrderHelper(object):
+class _BaseOrderHelper:
     """Base class for ordering helpers."""
 
     def __init__(self, rows_dimension, measures):
@@ -270,6 +312,8 @@ class _BaseOrderHelper(object):
         HelperCls = (
             _SortByMeasureHelper
             if order_spec.collation_method == CM.UNIVARIATE_MEASURE
+            else _SortByLabelHelper
+            if order_spec.collation_method == CM.LABEL
             else _OrderHelper
         )
         return HelperCls(rows_dimension, measures)._display_order
@@ -283,7 +327,7 @@ class _BaseOrderHelper(object):
         rows-dimension.
         """
         raise NotImplementedError(
-            "`%s` must implement `._display_order`" % type(self).__name__
+            f"`{type(self).__name__}` must implement `._display_order`"
         )  # pragma: no cover
 
     @lazyproperty
@@ -322,8 +366,15 @@ class _OrderHelper(_BaseOrderHelper):
         return CollatorCls.display_order(self._rows_dimension, self._empty_row_idxs)
 
 
-class _SortByMeasureHelper(_BaseOrderHelper):
-    """Orders rows by the value of a specified measure."""
+class _BaseSortByValueHelper(_BaseOrderHelper):
+    """A base class that orders elements by a set of values.
+
+    This class is intended only to serve as a base for the other sort-by-value classes
+    which must all provide their own implentations of `_element_values` and
+    `_subtotal_values`.
+
+    If `_display_order` encouters a ValueError, it falls back to the payload order.
+    """
 
     @lazyproperty
     def _display_order(self):
@@ -333,13 +384,65 @@ class _SortByMeasureHelper(_BaseOrderHelper):
         insertion, hiding, pruning, and ordering transforms specified in the
         rows-dimension.
         """
-        return SortByValueCollator.display_order(
-            self._rows_dimension,
-            self._element_values,
-            self._subtotal_values,
-            self._empty_row_idxs,
+        # --- fall back to payload order if sort-by-value failes
+        try:
+            return SortByValueCollator.display_order(
+                self._rows_dimension,
+                self._element_values,
+                self._subtotal_values,
+                self._empty_row_idxs,
+            )
+        except ValueError:
+            return PayloadOrderCollator.display_order(
+                self._rows_dimension, self._empty_row_idxs
+            )
+
+    @lazyproperty
+    def _element_values(self):
+        """Sequence of body values that form the basis for sort order.
+
+        Must be implemented by child classes.
+        """
+        raise NotImplementedError(  # pragma: no cover
+            "{type(self).__name__} must implement `._element_values`"
         )
 
+    @lazyproperty
+    def _subtotal_values(self):
+        """Sequence of subtotal values that form the basis for sort order.
+
+        Must be implemented by child classes.
+        """
+        raise NotImplementedError(  # pragma: no cover
+            f"{type(self).__name__} must implement `._subtotal_values`"
+        )
+
+
+class _SortByLabelHelper(_BaseSortByValueHelper):
+    """Orders rows by the value of a specified measure."""
+
+    @lazyproperty
+    def _element_values(self):
+        """Sequence of labels that form the basis for sort order.
+
+        There is one value per row and values appear in payload (dimension) element
+        order. These are only the "base" values and do not include insertions.
+        """
+        return np.array(self._rows_dimension.element_labels)
+
+    @lazyproperty
+    def _subtotal_values(self):
+        """Sequence of row-subtotal labels that contribute to the sort basis.
+
+        There is one value per row subtotal and values appear in payload (dimension)
+        insertion order.
+        """
+        return np.array(self._rows_dimension.subtotal_labels)
+
+
+class _SortByMeasureHelper(_BaseSortByValueHelper):
+    """Orders rows by the value of a specified measure."""
+
     @lazyproperty
     def _element_values(self):
         """Sequence of measure values that form the basis for sort order.
@@ -364,12 +467,14 @@ class _SortByMeasureHelper(_BaseOrderHelper):
             "percent_moe": "table_proportion_stderrs",
             "percent_stddev": "table_proportion_stddevs",
             "percent_stderr": "table_proportion_stderrs",
+            "population": "population_proportions",  # strictly proportional
+            "population_moe": "population_proportion_stderrs",  # strictly proportional
             "sum": "sums",
         }.get(measure_keyname)
 
         if measure_propname is None:
             raise ValueError(
-                "sort-by-value for measure '%s' is not yet supported" % measure_keyname
+                f"sort-by-value for measure '{measure_keyname}' is not yet supported"
             )
 
         return getattr(self._measures, measure_propname)
