@@ -2,10 +2,9 @@
 
 """Second-order measure collection and the individual measures it composes."""
 
-from __future__ import division
-
 import numpy as np
 
+from cr.cube.enums import DIMENSION_TYPE as DT
 from cr.cube.stripe.cubemeasure import CubeMeasures
 from cr.cube.stripe.insertion import NanSubtotals, SumSubtotals
 from cr.cube.util import lazyproperty
@@ -14,7 +13,7 @@ from cr.cube.util import lazyproperty
 # === MEASURE COLLECTION ===
 
 
-class StripeMeasures(object):
+class StripeMeasures:
     """Intended to be a singleton for a given cube-result.
 
     It will give the same values if duplicated, just sacrificing some time and memory
@@ -34,6 +33,18 @@ class StripeMeasures(object):
         """_Means measure object for this stripe."""
         return _Means(self._rows_dimension, self, self._cube_measures)
 
+    @lazyproperty
+    def population_proportions(self):
+        """_PopulationPrortion measure object for this stripe."""
+        return _PopulationProportions(self._rows_dimension, self, self._cube_measures)
+
+    @lazyproperty
+    def population_proportion_stderrs(self):
+        """_PopulationProportionStderrs measure object for this stripe."""
+        return _PopulationProportionStderrs(
+            self._rows_dimension, self, self._cube_measures
+        )
+
     @lazyproperty
     def pruning_base(self):
         """1D np.float64 ndarray of unweighted-N for each stripe row."""
@@ -120,7 +131,7 @@ class StripeMeasures(object):
 # === INDIVIDUAL MEASURES ===
 
 
-class _BaseSecondOrderMeasure(object):
+class _BaseSecondOrderMeasure:
     """Base class for all second-order measure objects."""
 
     def __init__(self, rows_dimension, measures, cube_measures):
@@ -136,7 +147,7 @@ class _BaseSecondOrderMeasure(object):
         The values appear in payload order.
         """
         raise NotImplementedError(
-            "`%s` must implement `.base_values`" % type(self).__name__
+            f"`{type(self).__name__}` must implement `.base_values`"
         )  # pragma: no cover
 
     @lazyproperty
@@ -154,12 +165,12 @@ class _BaseSecondOrderMeasure(object):
     def subtotal_values(self):
         """1D ndarray of subtotal value for each row-subtotal."""
         raise NotImplementedError(
-            "`%s` must implement `.subtotal_values`" % type(self).__name__
+            f"`{type(self).__name__}` must implement `.subtotal_values`"
         )  # pragma: no cover
 
     @lazyproperty
     def _unweighted_cube_counts(self):
-        """_BaseUnweightedCubeCounts subclass instance for this measure.
+        """_BaseCubeCounts for unweighted counts subclass instance for this measure.
 
         Provides cube measures associated with unweighted counts, including
         unweighted-counts and bases.
@@ -168,7 +179,7 @@ class _BaseSecondOrderMeasure(object):
 
     @lazyproperty
     def _weighted_cube_counts(self):
-        """_BaseWeightedCubeCounts subclass instance for this measure.
+        """_BaseCubeCounts for weighted counts subclass instance for this measure.
 
         Provides cube measures associated with weighted counts, including
         weighted-counts and table-margin.
@@ -197,6 +208,68 @@ class _Means(_BaseSecondOrderMeasure):
         return NanSubtotals.subtotal_values(self.base_values, self._rows_dimension)
 
 
+class _PopulationProportions(_BaseSecondOrderMeasure):
+    """Provides the population-proportions measure for a stripe.
+
+    When the variable is a categorical-date, we do not divide the population between the
+    categories, so the proportion is always 1. Otherwise it is equal to the table
+    proportions.
+
+    This is used to calculate the population_counts.
+    """
+
+    @lazyproperty
+    def base_values(self):
+        """1D np.float64 ndarray of population proportion for each row."""
+        proportions = self._measures.table_proportions.base_values
+        return (
+            np.repeat(1, proportions.shape)
+            if self._rows_dimension.dimension_type == DT.CAT_DATE
+            else proportions
+        )
+
+    @lazyproperty
+    def subtotal_values(self):
+        """1D np.float64 ndarray of population proportion for each row-subtotal."""
+        proportions = self._measures.table_proportions.subtotal_values
+        return (
+            np.repeat(1, proportions.shape)
+            if self._rows_dimension.dimension_type == DT.CAT_DATE
+            else proportions
+        )
+
+
+class _PopulationProportionStderrs(_BaseSecondOrderMeasure):
+    """Provides the population-proportion-standard-errors measure for a stripe.
+
+    When the variable is a categorical-date, we do not divide the population between the
+    categories, so the standard-error is always 0. Otherwise it is equal to the table
+    proportions.
+
+    This is used to calculate the population_counts_moe.
+    """
+
+    @lazyproperty
+    def base_values(self):
+        """1D np.float64 ndarray of population proportion for each row."""
+        stderrs = self._measures.table_proportion_stderrs.base_values
+        return (
+            np.repeat(0, stderrs.shape)
+            if self._rows_dimension.dimension_type == DT.CAT_DATE
+            else stderrs
+        )
+
+    @lazyproperty
+    def subtotal_values(self):
+        """1D np.float64 ndarray of population proportion for each row-subtotal."""
+        stderrs = self._measures.table_proportion_stderrs.subtotal_values
+        return (
+            np.repeat(0, stderrs.shape)
+            if self._rows_dimension.dimension_type == DT.CAT_DATE
+            else stderrs
+        )
+
+
 class _ScaledCounts(_BaseSecondOrderMeasure):
     """Provides access to table-totals related to numeric-values/scaled-counts."""
 
@@ -324,7 +397,7 @@ class _ScaledCounts(_BaseSecondOrderMeasure):
         Counts for rows that have not been assigned a numeric value are skipped.
         Otherwise, the values appear in payload order.
         """
-        return self._weighted_cube_counts.weighted_counts[self._has_numeric_value]
+        return self._weighted_cube_counts.counts[self._has_numeric_value]
 
 
 class _ShareSum(_BaseSecondOrderMeasure):
@@ -442,7 +515,7 @@ class _TableProportions(_BaseSecondOrderMeasure):
     def base_values(self):
         """1D np.float64 ndarray of table-proportion for each row of stripe."""
         weighted_counts = self._measures.weighted_counts.base_values
-        table_margin = self._weighted_cube_counts.table_margin
+        weighted_bases = self._weighted_cube_counts.bases
 
         # --- note that table-margin can be either scalar or 1D ndarray. When it is an
         # --- array (stripe is MR), its shape is the same as the weighted_counts, so the
@@ -450,25 +523,23 @@ class _TableProportions(_BaseSecondOrderMeasure):
 
         # --- do not propagate divide-by-zero warnings to stderr ---
         with np.errstate(divide="ignore", invalid="ignore"):
-            return weighted_counts / table_margin
+            return weighted_counts / weighted_bases
 
     @lazyproperty
     def subtotal_values(self):
         """1D np.float64 ndarray of sum for each row-subtotal."""
         subtotal_values = self._measures.weighted_counts.subtotal_values
-        table_margin = self._weighted_cube_counts.table_margin
+        weighted_table_base = self._weighted_cube_counts.table_base
 
-        # --- table-margin is an array when stripe is MR and the division below only
-        # --- works when table-margin is a scalar. An MR stripe can have no subtotals,
-        # --- so the right answer is always always np.array([]) in this case. Maintain
-        # --- the dtype so an int base-values array is not converted to float when the
-        # --- two are concatenated.
-        if isinstance(table_margin, np.ndarray):
+        # --- table-base is defined when stripe is MR and the division below only
+        # --- An Array stripe can have no subtotals, so the right answer is always
+        # --- always np.array([]) in this case.
+        if weighted_table_base is None:
             return np.array([])
 
         # --- do not propagate divide-by-zero warnings to stderr ---
         with np.errstate(divide="ignore", invalid="ignore"):
-            return subtotal_values / table_margin
+            return subtotal_values / weighted_table_base
 
 
 class _UnweightedBases(_BaseSecondOrderMeasure):
@@ -487,7 +558,7 @@ class _UnweightedBases(_BaseSecondOrderMeasure):
     def subtotal_values(self):
         """1D np.float64 ndarray of subtotal value for each row-subtotal."""
         # --- Background:
-        # --- 1. The base is the same for all rows of a CAT stripe.
+        # --- 1. The base is only defined for a CAT stripe.
         # --- 2. An MR stripe can have no subtotals.
         # --- The strategy here is to broadcast the table-base to the size of the
         # --- subtotals array for CAT, and return an empty array for MR.
@@ -528,7 +599,7 @@ class _UnweightedCounts(_BaseSecondOrderMeasure):
     @lazyproperty
     def base_values(self):
         """1D np.float64 ndarray of unweighted-count for each stripe base-row."""
-        return self._unweighted_cube_counts.unweighted_counts
+        return self._unweighted_cube_counts.counts
 
     @lazyproperty
     def subtotal_values(self):
@@ -555,7 +626,7 @@ class _WeightedBases(_BaseSecondOrderMeasure):
     def subtotal_values(self):
         """1D np.float64 ndarray of sum for each row-subtotal."""
         # --- Background:
-        # --- 1. weighted-base is the same for all rows, including subtotal rows.
+        # --- 1. The base is only defined for a CAT stripe.
         # --- 2. Only a CAT stripe can have subtotals; an MR stripe can't.
         # --- The strategy here is to broadcast the table-margin to the size of the
         # --- subtotals array for CAT, and return an empty array for MR.
@@ -571,7 +642,7 @@ class _WeightedBases(_BaseSecondOrderMeasure):
             return subtotal_values
 
         return np.broadcast_to(
-            self._weighted_cube_counts.table_margin, subtotal_values.shape
+            self._weighted_cube_counts.table_base, subtotal_values.shape
         )
 
     @lazyproperty
@@ -595,7 +666,7 @@ class _WeightedCounts(_BaseSecondOrderMeasure):
     @lazyproperty
     def base_values(self):
         """1D np.float64 ndarray of weighted-count for each row."""
-        return self._weighted_cube_counts.weighted_counts
+        return self._weighted_cube_counts.counts
 
     @lazyproperty
     def subtotal_values(self):
