@@ -5,19 +5,20 @@
 import numpy as np
 import pytest
 
+from cr.cube.enums import DIMENSION_TYPE as DT
 from cr.cube.cube import Cube
 from cr.cube.dimension import Dimension
 from cr.cube.stripe.cubemeasure import (
     _BaseCubeMeans,
-    _BaseUnweightedCubeCounts,
-    _BaseWeightedCubeCounts,
-    _CatUnweightedCubeCounts,
-    _CatWeightedCubeCounts,
+    _BaseCubeCounts,
+    _CatCubeCounts,
     CubeMeasures,
 )
 from cr.cube.stripe.measure import (
     _BaseSecondOrderMeasure,
     _Means,
+    _PopulationProportions,
+    _PopulationProportionStderrs,
     _ScaledCounts,
     StripeMeasures,
     _TableProportionStddevs,
@@ -33,13 +34,15 @@ from cr.cube.stripe.measure import (
 from ...unitutil import class_mock, instance_mock, property_mock
 
 
-class DescribeStripeMeasures(object):
+class DescribeStripeMeasures:
     """Unit test suite for `cr.cube.stripe.measure.StripeMeasures` object."""
 
     @pytest.mark.parametrize(
         "measure_prop_name, MeasureCls",
         (
             ("means", _Means),
+            ("population_proportions", _PopulationProportions),
+            ("population_proportion_stderrs", _PopulationProportionStderrs),
             ("scaled_counts", _ScaledCounts),
             ("table_proportion_stddevs", _TableProportionStddevs),
             ("table_proportion_stderrs", _TableProportionStderrs),
@@ -78,7 +81,7 @@ class DescribeStripeMeasures(object):
         self, request, _cube_measures_prop_, cube_measures_
     ):
         unweighted_cube_counts_ = instance_mock(
-            request, _BaseUnweightedCubeCounts, pruning_base=np.array([0, 2, 7])
+            request, _BaseCubeCounts, pruning_base=np.array([0, 2, 7])
         )
         cube_measures_.unweighted_cube_counts = unweighted_cube_counts_
         _cube_measures_prop_.return_value = cube_measures_
@@ -120,7 +123,7 @@ class DescribeStripeMeasures(object):
         return instance_mock(request, Dimension)
 
 
-class Describe_BaseSecondOrderMeasure(object):
+class Describe_BaseSecondOrderMeasure:
     """Unit test suite for `cr.cube.stripe.measure._BaseSecondOrderMeasure` object."""
 
     def it_gathers_the_blocks_for_the_measure(self, request):
@@ -135,7 +138,7 @@ class Describe_BaseSecondOrderMeasure(object):
     def it_provides_access_to_the_unweighted_cube_counts_object_to_help(
         self, request, cube_measures_
     ):
-        unweighted_cube_counts_ = instance_mock(request, _BaseUnweightedCubeCounts)
+        unweighted_cube_counts_ = instance_mock(request, _BaseCubeCounts)
         cube_measures_.unweighted_cube_counts = unweighted_cube_counts_
         measure = _BaseSecondOrderMeasure(None, None, cube_measures_)
 
@@ -144,7 +147,7 @@ class Describe_BaseSecondOrderMeasure(object):
     def it_provides_access_to_the_weighted_cube_counts_object_to_help(
         self, request, cube_measures_
     ):
-        weighted_cube_counts_ = instance_mock(request, _BaseWeightedCubeCounts)
+        weighted_cube_counts_ = instance_mock(request, _BaseCubeCounts)
         cube_measures_.weighted_cube_counts = weighted_cube_counts_
         measure = _BaseSecondOrderMeasure(None, None, cube_measures_)
 
@@ -157,7 +160,7 @@ class Describe_BaseSecondOrderMeasure(object):
         return instance_mock(request, CubeMeasures)
 
 
-class Describe_Means(object):
+class Describe_Means:
     """Unit test suite for `cr.cube.stripe.measure._Means` object."""
 
     def it_computes_its_base_values_to_help(self, request):
@@ -184,7 +187,151 @@ class Describe_Means(object):
         assert subtotal_values == pytest.approx([np.nan, np.nan], nan_ok=True)
 
 
-class Describe_ScaledCounts(object):
+class Describe_PopulationProportions:
+    """Unit test suite for `cr.cube.stripe.measure._PopulationProportions` object."""
+
+    @pytest.mark.parametrize(
+        "dimension_type, base_values, expected_value",
+        (
+            (DT.CAT, [0, 1], [0, 1]),
+            # --- it has all 1 base-values if dimension is cat date ---
+            (DT.CAT_DATE, [0, 1], [1, 1]),
+        ),
+    )
+    def it_computes_its_base_values_to_help(
+        self,
+        dimension_type,
+        base_values,
+        table_proportions_,
+        measures_,
+        rows_dimension_,
+        expected_value,
+    ):
+        rows_dimension_.dimension_type = dimension_type
+        table_proportions_.base_values = np.array(base_values)
+        measures_.table_proportions = table_proportions_
+        population_proportions = _PopulationProportions(
+            rows_dimension_, measures_, None
+        )
+
+        assert population_proportions.base_values.tolist() == expected_value
+
+    @pytest.mark.parametrize(
+        "dimension_type, subtotal_values, expected_value",
+        (
+            (DT.CAT, [0, 1], [0, 1]),
+            # --- it has all 1 subtotal-values if dimension is cat date ---
+            (DT.CAT_DATE, [0, 1], [1, 1]),
+            # --- and its ok with empty subtotals for cat-date ---
+            (DT.CAT_DATE, [], []),
+        ),
+    )
+    def it_computes_its_subtotal_values_to_help(
+        self,
+        dimension_type,
+        subtotal_values,
+        table_proportions_,
+        measures_,
+        rows_dimension_,
+        expected_value,
+    ):
+        rows_dimension_.dimension_type = dimension_type
+        table_proportions_.subtotal_values = np.array(subtotal_values)
+        measures_.table_proportions = table_proportions_
+        population_proportions = _PopulationProportions(
+            rows_dimension_, measures_, None
+        )
+
+        assert population_proportions.subtotal_values.tolist() == expected_value
+
+    # fixture components ---------------------------------------------
+
+    @pytest.fixture
+    def rows_dimension_(self, request):
+        return instance_mock(request, Dimension)
+
+    @pytest.fixture
+    def measures_(self, request):
+        return instance_mock(request, StripeMeasures)
+
+    @pytest.fixture
+    def table_proportions_(self, request):
+        return instance_mock(request, _TableProportions)
+
+
+class Describe_PopulationProportionStderrs:
+    """Unit test suite for `cr.cube.stripe.measure._PopulationProportionStderrs` object."""
+
+    @pytest.mark.parametrize(
+        "dimension_type, base_values, expected_value",
+        (
+            (DT.CAT, [0, 1], [0, 1]),
+            # --- it has all 0 base-values if dimension is cat date ---
+            (DT.CAT_DATE, [0, 1], [0, 0]),
+        ),
+    )
+    def it_computes_its_base_values_to_help(
+        self,
+        dimension_type,
+        base_values,
+        table_proportion_stderrs_,
+        measures_,
+        rows_dimension_,
+        expected_value,
+    ):
+        rows_dimension_.dimension_type = dimension_type
+        table_proportion_stderrs_.base_values = np.array(base_values)
+        measures_.table_proportion_stderrs = table_proportion_stderrs_
+        population_stderrs = _PopulationProportionStderrs(
+            rows_dimension_, measures_, None
+        )
+
+        assert population_stderrs.base_values.tolist() == expected_value
+
+    @pytest.mark.parametrize(
+        "dimension_type, subtotal_values, expected_value",
+        (
+            (DT.CAT, [0, 1], [0, 1]),
+            # --- it has all 0 subtotal-values if dimension is CAT_DATE ---
+            (DT.CAT_DATE, [0, 1], [0, 0]),
+            # --- and its ok with empty subtotals for CAT_DATE ---
+            (DT.CAT_DATE, [], []),
+        ),
+    )
+    def it_computes_its_subtotal_values_to_help(
+        self,
+        dimension_type,
+        subtotal_values,
+        table_proportion_stderrs_,
+        measures_,
+        rows_dimension_,
+        expected_value,
+    ):
+        rows_dimension_.dimension_type = dimension_type
+        table_proportion_stderrs_.subtotal_values = np.array(subtotal_values)
+        measures_.table_proportion_stderrs = table_proportion_stderrs_
+        population_stderrs = _PopulationProportionStderrs(
+            rows_dimension_, measures_, None
+        )
+
+        assert population_stderrs.subtotal_values.tolist() == expected_value
+
+    # fixture components ---------------------------------------------
+
+    @pytest.fixture
+    def rows_dimension_(self, request):
+        return instance_mock(request, Dimension)
+
+    @pytest.fixture
+    def measures_(self, request):
+        return instance_mock(request, StripeMeasures)
+
+    @pytest.fixture
+    def table_proportion_stderrs_(self, request):
+        return instance_mock(request, _TableProportionStderrs)
+
+
+class Describe_ScaledCounts:
     """Unit test suite for `cr.cube.stripe.measure._ScaledCounts` object."""
 
     @pytest.mark.parametrize(
@@ -329,7 +476,7 @@ class Describe_ScaledCounts(object):
         self, request, _has_numeric_value_prop_
     ):
         weighted_cube_counts_ = instance_mock(
-            request, _BaseWeightedCubeCounts, weighted_counts=np.array([1.1, 2.2, 3.3])
+            request, _BaseCubeCounts, counts=np.array([1.1, 2.2, 3.3])
         )
         property_mock(
             request,
@@ -373,7 +520,7 @@ class Describe_ScaledCounts(object):
         return property_mock(request, _ScaledCounts, "_weighted_counts")
 
 
-class Describe_TableProportionStddevs(object):
+class Describe_TableProportionStddevs:
     """Unit test suite for `cr.cube.stripe.measure._TableProportionStddevs` object."""
 
     def it_computes_its_base_values_to_help(
@@ -405,7 +552,7 @@ class Describe_TableProportionStddevs(object):
         return instance_mock(request, _TableProportionVariances)
 
 
-class Describe_TableProportionStderrs(object):
+class Describe_TableProportionStderrs:
     """Unit test suite for `cr.cube.stripe.measure._TableProportionStderrs` object."""
 
     def it_computes_its_base_values_to_help(
@@ -445,7 +592,7 @@ class Describe_TableProportionStderrs(object):
         return instance_mock(request, _WeightedBases)
 
 
-class Describe_TableProportionVariances(object):
+class Describe_TableProportionVariances:
     """Unit test suite for `cr.cube.stripe.measure._TableProportionVariances` object."""
 
     def it_computes_its_base_values_to_help(self, measures_, table_proportions_):
@@ -475,11 +622,11 @@ class Describe_TableProportionVariances(object):
         return instance_mock(request, _TableProportions)
 
 
-class Describe_TableProportions(object):
+class Describe_TableProportions:
     """Unit test suite for `cr.cube.stripe.measure._TableProportions` object."""
 
     @pytest.mark.parametrize(
-        "table_margin, expected_value",
+        "weighted_bases, expected_value",
         (
             (np.array([4.5, 6.7]), [0.7555556, 0.8358209]),
             (42.42, [0.08015087, 0.1320132]),
@@ -491,21 +638,21 @@ class Describe_TableProportions(object):
         weighted_counts_,
         _weighted_cube_counts_prop_,
         weighted_cube_counts_,
-        table_margin,
+        weighted_bases,
         expected_value,
     ):
         weighted_counts_.base_values = np.array([3.4, 5.6])
         measures_.weighted_counts = weighted_counts_
-        weighted_cube_counts_.table_margin = table_margin
+        weighted_cube_counts_.bases = weighted_bases
         _weighted_cube_counts_prop_.return_value = weighted_cube_counts_
         table_proportions = _TableProportions(None, measures_, None)
 
         assert table_proportions.base_values == pytest.approx(expected_value)
 
     @pytest.mark.parametrize(
-        "table_margin, expected_value",
+        "weighted_table_base, expected_value",
         (
-            (np.array([4.5, 6.7]), []),
+            (None, []),
             (42.42, [0.2310231, 0.1791608]),
         ),
     )
@@ -515,12 +662,12 @@ class Describe_TableProportions(object):
         weighted_counts_,
         _weighted_cube_counts_prop_,
         weighted_cube_counts_,
-        table_margin,
+        weighted_table_base,
         expected_value,
     ):
         weighted_counts_.subtotal_values = np.array([9.8, 7.6])
         measures_.weighted_counts = weighted_counts_
-        weighted_cube_counts_.table_margin = table_margin
+        weighted_cube_counts_.table_base = weighted_table_base
         _weighted_cube_counts_prop_.return_value = weighted_cube_counts_
         table_proportions = _TableProportions(None, measures_, None)
 
@@ -538,14 +685,14 @@ class Describe_TableProportions(object):
 
     @pytest.fixture
     def weighted_cube_counts_(self, request):
-        return instance_mock(request, _BaseWeightedCubeCounts)
+        return instance_mock(request, _BaseCubeCounts)
 
     @pytest.fixture
     def _weighted_cube_counts_prop_(self, request):
         return property_mock(request, _TableProportions, "_weighted_cube_counts")
 
 
-class Describe_UnweightedBases(object):
+class Describe_UnweightedBases:
     """Unit test suite for `cr.cube.stripe.measure._UnweightedBases` object."""
 
     def it_knows_its_base_values(
@@ -569,7 +716,7 @@ class Describe_UnweightedBases(object):
         SumSubtotals_ = class_mock(request, "cr.cube.stripe.measure.SumSubtotals")
         SumSubtotals_.subtotal_values.return_value = subtotal_values
         _unweighted_cube_counts_prop_.return_value = instance_mock(
-            request, _CatUnweightedCubeCounts, table_base=42
+            request, _CatCubeCounts, table_base=42
         )
         unweighted_bases = _UnweightedBases(rows_dimension_, None, None)
 
@@ -593,21 +740,21 @@ class Describe_UnweightedBases(object):
 
     @pytest.fixture
     def unweighted_cube_counts_(self, request):
-        return instance_mock(request, _BaseUnweightedCubeCounts)
+        return instance_mock(request, _BaseCubeCounts)
 
     @pytest.fixture
     def _unweighted_cube_counts_prop_(self, request):
         return property_mock(request, _UnweightedBases, "_unweighted_cube_counts")
 
 
-class Describe_UnweightedCounts(object):
+class Describe_UnweightedCounts:
     """Unit test suite for `cr.cube.stripe.measure._UnweightedCounts` object."""
 
     def it_knows_its_base_values(
         self, _unweighted_cube_counts_prop_, unweighted_cube_counts_
     ):
         _unweighted_cube_counts_prop_.return_value = unweighted_cube_counts_
-        unweighted_cube_counts_.unweighted_counts = np.array([1, 2, 3])
+        unweighted_cube_counts_.counts = np.array([1, 2, 3])
         unweighted_counts = _UnweightedCounts(None, None, None)
 
         assert unweighted_counts.base_values.tolist() == [1, 2, 3]
@@ -630,14 +777,14 @@ class Describe_UnweightedCounts(object):
 
     @pytest.fixture
     def unweighted_cube_counts_(self, request):
-        return instance_mock(request, _BaseUnweightedCubeCounts)
+        return instance_mock(request, _BaseCubeCounts)
 
     @pytest.fixture
     def _unweighted_cube_counts_prop_(self, request):
         return property_mock(request, _UnweightedCounts, "_unweighted_cube_counts")
 
 
-class Describe_WeightedBases(object):
+class Describe_WeightedBases:
     """Unit test suite for `cr.cube.stripe.measure._WeightedBases` object."""
 
     def it_knows_its_base_values(
@@ -667,7 +814,7 @@ class Describe_WeightedBases(object):
         SumSubtotals_ = class_mock(request, "cr.cube.stripe.measure.SumSubtotals")
         SumSubtotals_.subtotal_values.return_value = subtotal_values
         _weighted_cube_counts_prop_.return_value = instance_mock(
-            request, _CatWeightedCubeCounts, table_margin=42.24
+            request, _CatCubeCounts, table_base=42.24
         )
         weighted_bases = _WeightedBases(rows_dimension_, None, None)
 
@@ -691,21 +838,21 @@ class Describe_WeightedBases(object):
 
     @pytest.fixture
     def weighted_cube_counts_(self, request):
-        return instance_mock(request, _BaseWeightedCubeCounts)
+        return instance_mock(request, _BaseCubeCounts)
 
     @pytest.fixture
     def _weighted_cube_counts_prop_(self, request):
         return property_mock(request, _WeightedBases, "_weighted_cube_counts")
 
 
-class Describe_WeightedCounts(object):
+class Describe_WeightedCounts:
     """Unit test suite for `cr.cube.stripe.measure._WeightedCounts` object."""
 
     def it_computes_its_base_values_to_help(
         self, _weighted_cube_counts_prop_, weighted_cube_counts_
     ):
         _weighted_cube_counts_prop_.return_value = weighted_cube_counts_
-        weighted_cube_counts_.weighted_counts = np.array([1, 2, 3])
+        weighted_cube_counts_.counts = np.array([1, 2, 3])
         weighted_counts = _WeightedCounts(None, None, None)
 
         assert weighted_counts.base_values.tolist() == [1, 2, 3]
@@ -730,7 +877,7 @@ class Describe_WeightedCounts(object):
 
     @pytest.fixture
     def weighted_cube_counts_(self, request):
-        return instance_mock(request, _BaseWeightedCubeCounts)
+        return instance_mock(request, _BaseCubeCounts)
 
     @pytest.fixture
     def _weighted_cube_counts_prop_(self, request):
