@@ -26,7 +26,7 @@ from ..unitutil import (
 )
 
 
-class Describe_BaseCollator(object):
+class Describe_BaseCollator:
     """Unit-test suite for `cr.cube.collator._BaseCollator` object."""
 
     def it_provides_access_to_the_dimension_element_ids_to_help(self, dimension_):
@@ -68,7 +68,7 @@ class Describe_BaseCollator(object):
         return instance_mock(request, Dimension)
 
 
-class Describe_BaseAnchoredCollator(object):
+class Describe_BaseAnchoredCollator:
     """Unit-test suite for `cr.cube.collator._BaseAnchoredCollator` object."""
 
     def it_provides_an_interface_classmethod(self, request, dimension_):
@@ -246,57 +246,47 @@ class Describe_BaseAnchoredCollator(object):
         return instance_mock(request, Dimension)
 
 
-class DescribeExplicitOrderCollator(object):
+class DescribeExplicitOrderCollator:
     """Unit-test suite for `cr.cube.collator.ExplicitOrderCollator` object."""
 
     @pytest.mark.parametrize(
-        "element_ids, element_subvar_ids, element_id_order, expected_value",
+        "element_ids, element_id_order, expected_value",
         (
-            ((), [], [], ()),
+            ((), [], ()),
             (
                 (1, 2, 3),
-                [None, None, None],
                 [2, 3, 1],
                 ((0, 1, 2), (1, 2, 3), (2, 0, 1)),
             ),
             # --- element not mentioned in transform appears at end in payload order ---
-            ((1, 2, 3), [None, None, None], [], ((0, 0, 1), (1, 1, 2), (2, 2, 3))),
-            ((1, 2, 3), [None, None, None], [2], ((0, 1, 2), (1, 0, 1), (2, 2, 3))),
+            ((1, 2, 3), [], ((0, 0, 1), (1, 1, 2), (2, 2, 3))),
+            ((1, 2, 3), [2], ((0, 1, 2), (1, 0, 1), (2, 2, 3))),
             # --- id appearing in transform but not dimension is ignored ---
-            ((), [None, None, None], [3, 2, 1], ()),
+            ((), [3, 2, 1], ()),
             (
                 (1, 2, 3),
-                [None, None, None],
                 [2, 4, 1],
                 ((0, 1, 2), (1, 0, 1), (2, 2, 3)),
             ),
             # --- id repeated in transform is only used on first encounter ---
             (
                 (1, 2, 3),
-                [None, None, None],
                 [2, 2, 2],
                 ((0, 1, 2), (1, 0, 1), (2, 2, 3)),
             ),
             (
                 (1, 2, 3),
-                [None, None, None],
                 [3, 1, 3],
                 ((0, 2, 3), (1, 0, 1), (2, 1, 2)),
             ),
         ),
     )
     def it_computes_the_element_order_descriptors_to_help(
-        self, request, element_ids, element_subvar_ids, element_id_order, expected_value
+        self, request, element_ids, element_id_order, expected_value
     ):
         property_mock(
             request, ExplicitOrderCollator, "_element_ids", return_value=element_ids
         )
-        property_mock(
-            request,
-            ExplicitOrderCollator,
-            "_element_subvar_ids",
-            return_value=element_subvar_ids,
-        )
         order_spec_ = instance_mock(request, _OrderSpec, element_ids=element_id_order)
         property_mock(
             request,
@@ -309,7 +299,7 @@ class DescribeExplicitOrderCollator(object):
         assert collator._element_order_descriptors == expected_value
 
 
-class DescribePayloadOrderCollator(object):
+class DescribePayloadOrderCollator:
     """Unit-test suite for `cr.cube.collator.PayloadOrderCollator` object."""
 
     @pytest.mark.parametrize(
@@ -334,7 +324,7 @@ class DescribePayloadOrderCollator(object):
         assert collator._element_order_descriptors == expected_value
 
 
-class DescribeSortByValueCollator(object):
+class DescribeSortByValueCollator:
     """Unit-test suite for `cr.cube.collator.SortByValueCollator` object.
 
     SortByValueCollator computes element ordering for sort-by-value order transforms. It
@@ -397,6 +387,10 @@ class DescribeSortByValueCollator(object):
             ((), (1, 0), True, (8.0, 2.0, 4.0, 1.0), (2, 3)),
             # --- descending with both kinds of fixed idxs ---
             ((0,), (3,), True, (8.0, 2.0, 4.0, 1.0), (2, 1)),
+            # --- ascending sort with nans (at end in order) ---
+            ((), (), False, (8.0, np.nan, 2.0, np.nan), (2, 0, 1, 3)),
+            # --- descending sort with nans (at end in order) ---
+            ((), (), True, (8.0, np.nan, 2.0, np.nan), (0, 2, 1, 3)),
         ),
     )
     def it_computes_the_sorted_body_idxs_to_help(
@@ -419,7 +413,7 @@ class DescribeSortByValueCollator(object):
         assert collator._body_idxs == expected_value
 
     def it_computes_the_bottom_exclusion_idxs_to_help(
-        self, request, _iter_fixed_idxs_, _order_spec_prop_, order_spec_
+        self, _iter_fixed_idxs_, _order_spec_prop_, order_spec_
     ):
         _iter_fixed_idxs_.return_value = (n for n in (4, 0, 5, 2))
         _order_spec_prop_.return_value = order_spec_
@@ -484,6 +478,13 @@ class DescribeSortByValueCollator(object):
 
         assert collator._descending == expected_value
 
+    @pytest.mark.parametrize(
+        "value, expected",
+        ((0, False), (1.1, False), ("a", False), (np.nan, True)),
+    )
+    def it_can_compute_is_nan_to_help(self, value, expected):
+        assert SortByValueCollator._is_nan(value) == expected
+
     @pytest.mark.parametrize(
         "subtotal_values, descending, expected_value",
         (
