@@ -2,9 +2,6 @@
 
 """Unit test suite for `cr.cube.cubepart` module."""
 
-from __future__ import division
-
-import numpy as np
 import pytest
 
 from cr.cube.cube import Cube
@@ -17,7 +14,7 @@ from cr.cube.stripe.assembler import StripeAssembler
 from ..unitutil import class_mock, instance_mock, property_mock
 
 
-class DescribeCubePartition(object):
+class DescribeCubePartition:
     """Unit test suite for `cr.cube.cubepart.CubePartition` object."""
 
     def it_constructs_a_slice_with_its_factory_for_a_2D_cube(self, request, cube_):
@@ -223,22 +220,45 @@ class DescribeCubePartition(object):
         return property_mock(request, CubePartition, "_transforms_dict")
 
 
-class Describe_Slice(object):
+class Describe_Slice:
     """Unit test suite for `cr.cube.cubepart._Slice` object."""
 
-    def it_knows_the_column_unweighted_bases(self, _assembler_prop_, assembler_):
+    def it_provides_the_default_repr_when_enhanced_repr_fails(self):
+        cube = _Slice(None, None, None, None, None)
+
+        cube_repr = cube.__repr__()
+
+        assert cube_repr.startswith("<cr.cube.cubepart._Slice object at 0x")
+
+    @pytest.mark.parametrize(
+        "measure_name",
+        (
+            "column_unweighted_bases",
+            "column_weighted_bases",
+            "columns_scale_mean_stderr",
+            "columns_scale_mean",
+            "columns_scale_median",
+            "row_proportions",
+            "row_unweighted_bases",
+            "row_weighted_bases",
+            "rows_margin",
+            "rows_scale_mean",
+            "rows_scale_mean_stddev",
+            "rows_scale_mean_stderr",
+            "rows_scale_median",
+            "table_proportions",
+            "table_std_err",
+            "table_unweighted_bases",
+            "table_weighted_bases",
+        ),
+    )
+    def it_knows_assembled_measures(self, _assembler_prop_, assembler_, measure_name):
         _assembler_prop_.return_value = assembler_
-        assembler_.column_unweighted_bases = np.array([[0, 1], [2, 3]])
-        slice_ = _Slice(None, None, None, None, None)
+        setattr(assembler_, measure_name, [[1, 2], [3, 4]])
 
-        assert slice_.column_unweighted_bases.tolist() == [[0, 1], [2, 3]]
+        results = getattr(_Slice(None, None, None, None, None), measure_name)
 
-    def it_knows_the_column_weighted_bases(self, _assembler_prop_, assembler_):
-        _assembler_prop_.return_value = assembler_
-        assembler_.column_weighted_bases = np.array([[0.0, 1.1], [2.2, 3.3]])
-        slice_ = _Slice(None, None, None, None, None)
-
-        assert slice_.column_weighted_bases.tolist() == [[0.0, 1.1], [2.2, 3.3]]
+        assert results == [[1, 2], [3, 4]]
 
     @pytest.mark.parametrize(
         ("shape", "expected_value"),
@@ -252,25 +272,6 @@ class Describe_Slice(object):
 
         assert is_empty is expected_value
 
-    def it_provides_the_secondary_pairwise_indices(
-        self,
-        _alpha_alt_prop_,
-        _only_larger_prop_,
-        PairwiseSignificance_,
-        dimension_types_prop_,
-    ):
-        PairwiseSignificance_.pairwise_indices.return_value = [[(0,), (1,)], [(), ()]]
-        _alpha_alt_prop_.return_value = 0.42
-        _only_larger_prop_.return_value = False
-        slice_ = _Slice(None, None, None, None, None)
-
-        pairwise_indices_alt = slice_.pairwise_indices_alt
-
-        PairwiseSignificance_.pairwise_indices.assert_called_once_with(
-            slice_, 0.42, False
-        )
-        assert pairwise_indices_alt == [[(0,), (1,)], [(), ()]]
-
     def but_it_returns_None_when_no_secondary_alpha_specified(
         self, _alpha_alt_prop_, dimension_types_prop_
     ):
@@ -285,31 +286,27 @@ class Describe_Slice(object):
 
         assert population_fraction == 0.5
 
-    def it_knows_the_row_unweighted_bases(self, _assembler_prop_, assembler_):
+    def it_provides_the_population_counts(self, _assembler_prop_, assembler_, cube_):
+        assembler_.population_proportions = 0.3
         _assembler_prop_.return_value = assembler_
-        assembler_.row_unweighted_bases = np.array([[3, 2], [1, 0]])
-        slice_ = _Slice(None, None, None, None, None)
+        cube_.population_fraction = 0.1
+        population = 20
 
-        assert slice_.row_unweighted_bases.tolist() == [[3, 2], [1, 0]]
+        slice_ = _Slice(cube_, None, None, population, None)
 
-    def it_knows_the_row_weighted_bases(self, _assembler_prop_, assembler_):
+        assert slice_.population_counts == pytest.approx(0.6)
+
+    def it_provides_the_population_count_moes(
+        self, _assembler_prop_, assembler_, cube_
+    ):
+        assembler_.population_std_err = 0.3
         _assembler_prop_.return_value = assembler_
-        assembler_.row_weighted_bases = np.array([[3.3, 2.2], [1.1, 0.0]])
-        slice_ = _Slice(None, None, None, None, None)
+        cube_.population_fraction = 0.1
+        population = 20
 
-        assert slice_.row_weighted_bases.tolist() == [[3.3, 2.2], [1.1, 0.0]]
+        slice_ = _Slice(cube_, None, None, population, None)
 
-    def it_knows_the_rows_margin(self, _assembler_prop_, assembler_):
-        _assembler_prop_.return_value = assembler_
-        assembler_.rows_margin = [[1, 2], [3, 4]]
-
-        assert _Slice(None, None, None, None, None).rows_margin == [[1, 2], [3, 4]]
-
-    def it_knows_the_row_proportion(self, _assembler_prop_, assembler_):
-        _assembler_prop_.return_value = assembler_
-        assembler_.row_proportions = [[1, 2], [3, 4]]
-
-        assert _Slice(None, None, None, None, None).row_proportions == [[1, 2], [3, 4]]
+        assert slice_.population_counts_moe == pytest.approx(0.6 * 1.959964)
 
     def it_provides_the_secondary_scale_mean_pairwise_indices(
         self, _alpha_alt_prop_, _only_larger_prop_, PairwiseSignificance_
@@ -338,30 +335,6 @@ class Describe_Slice(object):
 
         assert slice_.columns_scale_mean_pairwise_indices_alt is None
 
-    @pytest.mark.parametrize(
-        "measure",
-        (
-            "rows_scale_mean",
-            "columns_scale_mean",
-            "rows_scale_mean_stddev",
-            "columns_scale_mean_stddev",
-            "rows_scale_median",
-            "columns_scale_median",
-        ),
-    )
-    def it_knows_the_scale_marginals(
-        self, request, _assembler_prop_, assembler_, measure
-    ):
-        _assembler_prop_.return_value = assembler_
-        setattr(
-            assembler_,
-            measure,
-            np.array([[2.2, 3.3], [0.0, 1.1]]),
-        )
-        slice_ = _Slice(None, None, None, None, None)
-
-        assert getattr(slice_, measure).tolist() == [[2.2, 3.3], [0.0, 1.1]]
-
     @pytest.mark.parametrize(
         "dimensions_dicts, expected_value",
         (
@@ -400,20 +373,6 @@ class Describe_Slice(object):
 
         assert slice_.selected_category_labels == expected_value
 
-    def it_knows_the_table_unweighted_bases(self, _assembler_prop_, assembler_):
-        _assembler_prop_.return_value = assembler_
-        assembler_.table_unweighted_bases = np.array([[2, 3], [0, 1]])
-        slice_ = _Slice(None, None, None, None, None)
-
-        assert slice_.table_unweighted_bases.tolist() == [[2, 3], [0, 1]]
-
-    def it_knows_the_table_weighted_bases(self, _assembler_prop_, assembler_):
-        _assembler_prop_.return_value = assembler_
-        assembler_.table_weighted_bases = np.array([[2.2, 3.3], [0.0, 1.1]])
-        slice_ = _Slice(None, None, None, None, None)
-
-        assert slice_.table_weighted_bases.tolist() == [[2.2, 3.3], [0.0, 1.1]]
-
     def it_constructs_its_assembler_instance_to_help(
         self, request, cube_, _dimensions_prop_, dimension_, assembler_
     ):
@@ -472,9 +431,16 @@ class Describe_Slice(object):
         return property_mock(request, _Slice, "shape")
 
 
-class Describe_Strand(object):
+class Describe_Strand:
     """Unit test suite for `cr.cube.cubepart._Strand` object."""
 
+    def it_provides_the_default_repr_when_enhanced_repr_fails(self):
+        cube = _Strand(None, None, None, None, None, None)
+
+        cube_repr = cube.__repr__()
+
+        assert cube_repr.startswith("<cr.cube.cubepart._Strand object at 0x")
+
     def it_knows_which_of_its_rows_are_inserted(self, _assembler_prop_, assembler_):
         _assembler_prop_.return_value = assembler_
         assembler_.inserted_row_idxs = (1, 3, 5)
@@ -507,6 +473,34 @@ class Describe_Strand(object):
 
         assert population_fraction == 0.5
 
+    def it_provides_the_population_count(
+        self,
+        cube_,
+        _assembler_prop_,
+        assembler_,
+    ):
+        assembler_.population_proportions = 0.3
+        _assembler_prop_.return_value = assembler_
+        cube_.population_fraction = 0.1
+        population = 20
+        strand_ = _Strand(cube_, None, population, None, None, None)
+
+        assert strand_.population_counts == pytest.approx(0.6)
+
+    def it_provides_the_population_counts_moe(
+        self,
+        cube_,
+        _assembler_prop_,
+        assembler_,
+    ):
+        assembler_.population_proportion_stderrs = 0.3
+        _assembler_prop_.return_value = assembler_
+        cube_.population_fraction = 0.1
+        population = 20
+        strand_ = _Strand(cube_, None, population, None, None, None)
+
+        assert strand_.population_counts_moe == pytest.approx(0.6 * 1.959964)
+
     def it_knows_its_selected_categories_labels(self, _dimensions_prop_):
         _dimensions_prop_.return_value = [Dimension({"references": {}}, None, None)]
         strand_ = _Strand(None, None, None, None, None, None)
@@ -536,7 +530,7 @@ class Describe_Strand(object):
         return property_mock(request, _Strand, "shape")
 
 
-class Describe_Nub(object):
+class Describe_Nub:
     """Unit test suite for `cr.cube.cubepart._Nub` object."""
 
     @pytest.mark.parametrize(
