@@ -13,6 +13,7 @@ from cr.cube.dimension import (
     _BaseElements,
     Dimension,
     _DimensionFactory,
+    _ElementIdShim,
     _Element,
     _ElementTransforms,
     _OrderSpec,
@@ -39,7 +40,7 @@ from ..unitutil import (
 )
 
 
-class Describe_BaseDimensions(object):
+class Describe_BaseDimensions:
     def it_has_sequence_behaviors(self, _dimensions_prop_):
         _dimensions_prop_.return_value = (0, 1, 2)
         base_dimensions = _BaseDimensions()
@@ -61,7 +62,7 @@ class Describe_BaseDimensions(object):
         return property_mock(request, _BaseDimensions, "_dimensions")
 
 
-class DescribeAllDimensions(object):
+class DescribeAllDimensions:
     """Unit-test suite for `cr.cube.dimension.AllDimensions` object."""
 
     def it_provides_access_to_its_ApparentDimensions(
@@ -127,7 +128,7 @@ class DescribeAllDimensions(object):
         return property_mock(request, AllDimensions, "_dimensions")
 
 
-class Describe_ApparentDimensions(object):
+class Describe_ApparentDimensions:
     def it_stores_its_dimensions_in_a_tuple_to_help(self, request):
         all_dimensions_ = tuple(
             instance_mock(request, Dimension, name="dim-%d" % idx, dimension_type=dt)
@@ -140,7 +141,7 @@ class Describe_ApparentDimensions(object):
         assert dimensions == all_dimensions_[:2]
 
 
-class Describe_DimensionFactory(object):
+class Describe_DimensionFactory:
     def it_provides_an_interface_classmethod(
         self, request, dimension_dicts_, _init_, _iter_dimensions_
     ):
@@ -233,7 +234,7 @@ class Describe_DimensionFactory(object):
         return property_mock(request, _DimensionFactory, "_raw_dimensions")
 
 
-class Describe_RawDimension(object):
+class Describe_RawDimension:
     def it_provides_access_to_the_dimension_dict(self):
         dimension_dict_ = {"dimension": "dict"}
         raw_dimension = _RawDimension(dimension_dict_, None)
@@ -492,7 +493,7 @@ class Describe_RawDimension(object):
         return method_mock(request, _RawDimension, "_resolve_categorical")
 
 
-class DescribeDimension(object):
+class DescribeDimension:
     """Unit-test suite for `cr.cube.dimension.Dimension` object."""
 
     @pytest.mark.parametrize(
@@ -526,6 +527,12 @@ class DescribeDimension(object):
         )
         assert Dimension(None, None).element_ids == (1, 2, 3, 4, 5, 6)
 
+    def it_knows_its_element_labels(self, request, valid_elements_prop_):
+        valid_elements_prop_.return_value = (
+            instance_mock(request, _Element, label="lbl %s" % (i + 1)) for i in range(3)
+        )
+        assert Dimension(None, None).element_labels == ("lbl 1", "lbl 2", "lbl 3")
+
     def it_computes_its_hidden_idxs(self, request, valid_elements_prop_):
         valid_elements_prop_.return_value = (
             instance_mock(request, _Element, is_hidden=bool(i % 2)) for i in range(7)
@@ -666,6 +673,13 @@ class DescribeDimension(object):
         _Subtotals_.assert_called_once_with(insertion_dicts, valid_elements_)
         assert subtotals is subtotals_
 
+    def it_knows_its_subtotal_labels(self, request, subtotals_prop_):
+        subtotals_prop_.return_value = (
+            instance_mock(request, _Subtotal, label="lbl %s" % (i + 1))
+            for i in range(3)
+        )
+        assert Dimension(None, None).subtotal_labels == ("lbl 1", "lbl 2", "lbl 3")
+
     @pytest.mark.parametrize("dimension_type", (DT.MR, DT.CA_SUBVAR))
     def but_it_suppresses_any_subtotals_on_an_array_dimension(
         self,
@@ -714,6 +728,10 @@ class DescribeDimension(object):
     def subtotals_(self, request):
         return instance_mock(request, _Subtotals)
 
+    @pytest.fixture
+    def subtotals_prop_(self, request):
+        return property_mock(request, Dimension, "subtotals")
+
     @pytest.fixture
     def valid_elements_(self, request):
         return instance_mock(request, _ValidElements)
@@ -723,7 +741,7 @@ class DescribeDimension(object):
         return property_mock(request, Dimension, "valid_elements")
 
 
-class Describe_BaseElements(object):
+class Describe_BaseElements:
     """Unit-test suite for `cr.cube.dimension._BaseElements` object."""
 
     def it_has_sequence_behaviors(self, request, _elements_prop_):
@@ -798,7 +816,7 @@ class Describe_BaseElements(object):
         return property_mock(request, _BaseElements, "_elements")
 
 
-class Describe_AllElements(object):
+class Describe_AllElements:
     """Unit-test suite for `cr.cube.dimension._AllElements` object."""
 
     def it_provides_access_to_the_ValidElements_object(
@@ -877,51 +895,52 @@ class Describe_AllElements(object):
         )
 
     @pytest.mark.parametrize(
-        "element_transform, dimension_type, element_dict, expected_value",
+        "dim_xforms, element_dicts, dim_type, expected_value",
         (
             (
-                {"S2": {"hide": True}, "key": "subvar_id"},
-                DT.NUM_ARRAY,
-                {"id": 1, "value": {"references": {"alias": "A1"}, "id": "S2"}},
-                "S2",
+                {"insertions": [{"name": "A&B", "hide": True}]},
+                [
+                    {"id": 1, "value": {"id": "A&B"}},
+                    {"id": 2, "value": {"id": "0004"}},
+                ],
+                DT.MR,
+                {1: {"hide": True}},
             ),
             (
-                {"A1": {"hide": True}, "key": "alias"},
-                DT.NUM_ARRAY,
-                {"id": 1, "value": {"references": {"alias": "A1"}, "id": "S2"}},
-                "A1",
+                {
+                    "insertions": [{"name": "A&B", "hide": True}],
+                    "elements": {2: {"hide": True}},
+                },
+                [
+                    {"id": 1, "value": {"id": "A&B"}},
+                    {"id": 2, "value": {"id": "0004"}},
+                ],
+                DT.MR,
+                {1: {"hide": True}, 2: {"hide": True}},
             ),
             (
-                {"1": {"hide": True}},
-                DT.CA,
-                {"id": 1, "value": {"references": {"alias": "A1"}, "id": "S2"}},
-                "S2",
+                {
+                    "insertions": [{"name": "A&B", "hide": True}],
+                    "elements": {2: {"hide": True}},
+                },
+                [
+                    {"id": 1, "value": {"id": "A&B"}},
+                    {"id": 2, "value": {"id": "0004"}},
+                ],
+                DT.CAT,
+                {2: {"hide": True}},  # --- CAT insertions don't get updated
             ),
-            (
-                {"A1": {"hide": True}, "key": "alias"},
-                DT.NUM_ARRAY,
-                {"id": 1, "value": {"references": {"alias": ""}, "id": "S2"}},
-                1,
-            ),
-            (
-                {"A1": {"hide": True}, "key": "alias"},
-                DT.NUM_ARRAY,
-                {"id": 1, "value": {"references": {"alias": None}, "id": "S2"}},
-                1,
-            ),
-            ({"1": {"hide": True}}, DT.CAT, {"id": 1, "name": "Male"}, 1),
-            ({"0001": {"hide": True}}, DT.CAT, {"id": 1, "name": "Male"}, 1),
         ),
     )
-    def it_knows_its_element_id_from_dict(
-        self, element_transform, dimension_type, element_dict, expected_value
+    def it_knows_its_mr_insertions_elements_transforms_from_transforms_dict(
+        self, dim_xforms, element_dicts, dim_type, expected_value, _element_dicts_prop_
     ):
-        dimension_transforms_dict = {"elements": element_transform}
-        all_elements = _AllElements(None, dimension_transforms_dict, dimension_type)
+        _element_dicts_prop_.return_value = element_dicts
+        all_elements = _AllElements(None, dim_xforms, dim_type)
 
-        _element_id_from_dict = all_elements._element_id_from_dict(element_dict)
+        elements_transforms = all_elements._elements_transforms
 
-        assert _element_id_from_dict == expected_value
+        assert elements_transforms == expected_value
 
     # fixture components ---------------------------------------------
 
@@ -954,7 +973,7 @@ class Describe_AllElements(object):
         return instance_mock(request, _ValidElements)
 
 
-class Describe_ValidElements(object):
+class Describe_ValidElements:
     """Unit-test suite for `cr.cube.dimension._ValidElements` object."""
 
     def it_gets_its_Element_objects_from_an_AllElements_object(self, request):
@@ -971,7 +990,209 @@ class Describe_ValidElements(object):
         assert elements == (elements_[0], elements_[2])
 
 
-class Describe_Element(object):
+class Describe_ElementIdShim:
+    """Unit-test suite for `cr.cube.dimension._ElementIdShim` object."""
+
+    def it_provides_the_shimmed_dimension_dict_for_subvars(self, _subvar_aliases_prop_):
+        _subvar_aliases_prop_.return_value = tuple(("alias1", "alias2"))
+        dimension_dict = {
+            "type": {
+                "elements": [{"id": 1, "element_info": 100}, {"id": 2}],
+                "other": "in type",
+            },
+            "another": "outside type",
+        }
+        shim_ = _ElementIdShim(DT.MR_SUBVAR, dimension_dict, None)
+
+        assert shim_.shimmed_dimension_dict == {
+            "type": {
+                "elements": [{"id": "alias1", "element_info": 100}, {"id": "alias2"}],
+                "other": "in type",
+            },
+            "another": "outside type",
+        }
+
+    def but_non_subvariable_dimension_is_left_alone(self):
+        dimension_dict = {"dimension": "dictionary"}
+        shim_ = _ElementIdShim(DT.CAT, dimension_dict, None)
+
+        assert shim_.shimmed_dimension_dict == dimension_dict
+
+    def it_provides_the_shimmed_dimension_transform_dict_for_subvars(
+        self, _replaced_element_transforms_, _replaced_order_element_ids_
+    ):
+        dimension_transforms_dict = {
+            "elements": "all_elements",
+            "order": {"element_ids": "a", "ignored": "string"},
+            "another": "ignored",
+        }
+        _replaced_element_transforms_.return_value = {"replaced": "element_transforms"}
+        _replaced_order_element_ids_.return_value = {"replaced": "ids"}
+        shim_ = _ElementIdShim(DT.MR_SUBVAR, None, dimension_transforms_dict)
+
+        assert shim_.shimmed_dimension_transforms_dict == {
+            "elements": {"replaced": "element_transforms"},
+            "order": {"element_ids": {"replaced": "ids"}, "ignored": "string"},
+            "another": "ignored",
+        }
+        _replaced_element_transforms_.assert_called_once_with(shim_, "all_elements")
+        _replaced_order_element_ids_.assert_called_once_with(shim_, "a")
+
+    def but_it_skips_replacing_if_not_present(
+        self, _replaced_element_transforms_, _replaced_order_element_ids_
+    ):
+        dimension_transforms_dict = {
+            "order": {"ignored": "string"},
+            "another": "ignored",
+        }
+        shim_ = _ElementIdShim(DT.MR_SUBVAR, None, dimension_transforms_dict)
+
+        assert shim_.shimmed_dimension_transforms_dict == dimension_transforms_dict
+        _replaced_element_transforms_.assert_not_called()
+        _replaced_order_element_ids_.assert_not_called()
+
+    def and_it_skips_replacing_if_not_subvars(
+        self, _replaced_element_transforms_, _replaced_order_element_ids_
+    ):
+        dimension_transforms_dict = {
+            "elements": {"replaced": "element_transforms"},
+            "order": {"element_ids": {"replaced": "ids"}, "ignored": "string"},
+            "another": "ignored",
+        }
+        shim_ = _ElementIdShim(DT.CAT, None, dimension_transforms_dict)
+
+        assert shim_.shimmed_dimension_transforms_dict == dimension_transforms_dict
+        _replaced_element_transforms_.assert_not_called()
+        _replaced_order_element_ids_.assert_not_called()
+
+    @pytest.mark.parametrize(
+        "id, expected",
+        (
+            ("all", "all"),
+            ("0003", "alias2"),
+            ("1", "all"),
+            (3, "alias1"),
+            (2, "alias2"),
+            (21, None),
+            ("xyz", None),
+        ),
+    )
+    def it_translates_element_ids_for_subvariables(
+        self,
+        _raw_element_id_prop_,
+        _subvar_aliases_prop_,
+        _subvar_ids_prop_,
+        id,
+        expected,
+    ):
+        _subvar_aliases_prop_.return_value = tuple(("all", "alias1", "alias2"))
+        _subvar_ids_prop_.return_value = tuple(("0001", "all", "0003"))
+        _raw_element_id_prop_.return_value = tuple(("1", 3, "all"))
+
+        shim_ = _ElementIdShim(DT.MR_SUBVAR, None, None)
+
+        assert shim_.translate_element_id(id) == expected
+
+    def but_it_leaves_non_array_ids_alone(self):
+        _ElementIdShim(DT.CAT, None, None).translate_element_id(25) == 25
+
+    def it_provides_the_raw_element_ids_to_help(self):
+        dimension_dict = {"type": {"elements": [{"id": 1}, {"id": "b"}]}}
+        shim_ = _ElementIdShim(None, dimension_dict, None)
+
+        assert shim_._raw_element_ids == tuple((1, "b"))
+
+    def it_replaces_the_element_transforms_to_help(
+        self, _raw_element_id_prop_, _subvar_aliases_prop_, _subvar_ids_prop_
+    ):
+        element_transforms = {
+            "xxx": {"transform": "object"},
+            "abc": {"another": "transform"},
+        }
+        _raw_element_id_prop_.return_value = tuple((1,))
+        _subvar_aliases_prop_.return_value = tuple(("alias2",))
+        _subvar_ids_prop_.return_value = tuple(("abc",))
+
+        shim_ = _ElementIdShim(DT.MR_SUBVAR, None, None)
+
+        assert shim_._replaced_element_transforms(element_transforms) == {
+            "alias2": {"another": "transform"}
+        }
+
+    def it_replaces_the_element_transforms_to_help_with_alias_keys(self):
+        element_transforms = {
+            "alias1": {"transform": "object"},
+            "alias2": {"another": "transform"},
+            "key": "alias",
+        }
+        shim_ = _ElementIdShim(None, None, None)
+
+        assert (
+            shim_._replaced_element_transforms(element_transforms) == element_transforms
+        )
+
+    def it_replaces_the_element_transforms_to_help_with_subvar_id_keys(
+        self, _subvar_aliases_prop_, _subvar_ids_prop_
+    ):
+        _subvar_aliases_prop_.return_value = tuple(("alias1", "alias2", "alias3"))
+        _subvar_ids_prop_.return_value = tuple(("xyz", "s2", "abc"))
+        element_transforms = {
+            "s1": {"transform": "object"},
+            "s2": {"another": "transform"},
+            "key": "subvar_id",
+        }
+        shim_ = _ElementIdShim(None, None, None)
+
+        assert shim_._replaced_element_transforms(element_transforms) == {
+            "alias2": {"another": "transform"}
+        }
+
+    def it_provides_the_subvar_ids_to_help(self):
+        dimension_dict = {
+            "type": {"elements": [{"value": {"id": "a"}}, {"value": {"id": 2}}]}
+        }
+        shim_ = _ElementIdShim(None, dimension_dict, None)
+
+        assert shim_._subvar_ids == tuple(("a", 2))
+
+    def it_provides_the_subvar_aliases_to_help(self):
+        dimension_dict = {
+            "type": {
+                "elements": [
+                    {"id": 1, "value": {"references": {"alias": "x"}}},
+                    {"id": 2, "value": {"references": {"alias": "y"}}},
+                    {"id": 3},
+                ]
+            }
+        }
+        shim_ = _ElementIdShim(None, dimension_dict, None)
+
+        assert shim_._subvar_aliases == tuple(("x", "y", 3))
+
+    # fixture components ---------------------------------------------
+
+    @pytest.fixture
+    def _raw_element_id_prop_(self, request):
+        return property_mock(request, _ElementIdShim, "_raw_element_ids")
+
+    @pytest.fixture
+    def _replaced_element_transforms_(self, request):
+        return method_mock(request, _ElementIdShim, "_replaced_element_transforms")
+
+    @pytest.fixture
+    def _replaced_order_element_ids_(self, request):
+        return method_mock(request, _ElementIdShim, "_replaced_order_element_ids")
+
+    @pytest.fixture
+    def _subvar_aliases_prop_(self, request):
+        return property_mock(request, _ElementIdShim, "_subvar_aliases")
+
+    @pytest.fixture
+    def _subvar_ids_prop_(self, request):
+        return property_mock(request, _ElementIdShim, "_subvar_ids")
+
+
+class Describe_Element:
     """Unit-test suite for `cr.cube.dimension._Element` object."""
 
     def it_knows_its_element_id(self):
@@ -1085,7 +1306,7 @@ class Describe_Element(object):
         return instance_mock(request, _ElementTransforms)
 
 
-class DescribeElementTransforms(object):
+class DescribeElementTransforms:
     """Unit-test suite for `cr.cube.dimension._ElementTransforms` object."""
 
     @pytest.mark.parametrize(
@@ -1138,7 +1359,7 @@ class DescribeElementTransforms(object):
         assert name == expected_value
 
 
-class Describe_OrderSpec(object):
+class Describe_OrderSpec:
     """Unit-test suite for `cr.cube.dimension._OrderSpec` object."""
 
     @pytest.mark.parametrize(
@@ -1282,7 +1503,7 @@ class Describe_OrderSpec(object):
         return property_mock(request, _OrderSpec, "_order_dict")
 
 
-class Describe_Subtotals(object):
+class Describe_Subtotals:
     """Unit-test suite for `cr.cube.dimension._Subtotals` object."""
 
     def it_has_sequence_behaviors(self, request, _subtotals_prop_):
@@ -1426,7 +1647,7 @@ class Describe_Subtotals(object):
         return instance_mock(request, _ValidElements)
 
 
-class Describe_Subtotal(object):
+class Describe_Subtotal:
     """Unit-test suite for `cr.cube.dimension._Subtotal` object."""
 
     @pytest.mark.parametrize(
